searchData={"items":[{"type":"module","title":"Money","doc":"Defines a `Money` struct along with convenience methods for working with currencies.","ref":"Money.html"},{"type":"module","title":"Examples - Money","doc":"iex> money = Money.new(500, :USD)\n    %Money{amount: 500, currency: :USD}\n    iex> money = Money.add(money, 550)\n    %Money{amount: 1050, currency: :USD}\n    iex> Money.to_string(money)\n    \"$10.50\"","ref":"Money.html#module-examples"},{"type":"module","title":"Configuration - Money","doc":"You can set defaults in your Mix configuration to make working with `Money` a little easier.\n\n    config :money,\n      default_currency: :EUR,                    # this allows you to do Money.new(100)\n      separator: \".\",                            # change the default thousands separator for Money.to_string\n      delimiter: \",\",                            # change the default decimal delimiter for Money.to_string\n      symbol: false,                             # don’t display the currency symbol in Money.to_string\n      symbol_on_right: false,                    # position the symbol\n      symbol_space: false,                       # add a space between symbol and number\n      fractional_unit: true,                     # display units after the delimiter\n      strip_insignificant_zeros: false,          # don’t display the insignificant zeros or the delimiter\n      code: false,                               # add the currency code after the number\n      minus_sign_first: true,                    # display the minus sign before the currency symbol for Money.to_string\n      strip_insignificant_fractional_unit: false # don't display the delimiter or fractional units if the fractional units are only insignificant zeros","ref":"Money.html#module-configuration"},{"type":"function","title":"Money.abs/1","doc":"Returns a `Money` with the arithmetical absolute of the amount.","ref":"Money.html#abs/1"},{"type":"function","title":"Examples - Money.abs/1","doc":"iex> Money.new(-100, :USD) |> Money.abs\n    %Money{amount: 100, currency: :USD}\n\n    iex> Money.new(100, :USD) |> Money.abs\n    %Money{amount: 100, currency: :USD}","ref":"Money.html#abs/1-examples"},{"type":"function","title":"Money.add/2","doc":"Adds two `Money` together or an integer (cents) amount to a `Money`","ref":"Money.html#add/2"},{"type":"function","title":"Examples - Money.add/2","doc":"iex> Money.add(Money.new(100, :USD), Money.new(50, :USD))\n    %Money{amount: 150, currency: :USD}\n\n    iex> Money.add(Money.new(100, :USD), 50)\n    %Money{amount: 150, currency: :USD}\n\n    iex> Money.add(Money.new(100, :USD), 5.55)\n    %Money{amount: 655, currency: :USD}","ref":"Money.html#add/2-examples"},{"type":"function","title":"Money.cmp/2","doc":"Compares two `Money` structs with each other.\nThey must each be of the same currency and then their amounts are compared.\nIf the first amount is larger than the second `:gt` is returned, if less than\n`:lt` is returned, if both amounts are equal `:eq` is returned.\n\nSee `compare/2` for a similar function that returns `-1`, `0` or `1` instead.","ref":"Money.html#cmp/2"},{"type":"function","title":"Examples - Money.cmp/2","doc":"iex> Money.cmp(Money.new(100, :USD), Money.new(100, :USD))\n    :eq\n\n    iex> Money.cmp(Money.new(100, :USD), Money.new(101, :USD))\n    :lt\n\n    iex> Money.cmp(Money.new(101, :USD), Money.new(100, :USD))\n    :gt","ref":"Money.html#cmp/2-examples"},{"type":"function","title":"Money.compare/2","doc":"Compares two `Money` structs with each other.\nThey must each be of the same currency and then their amounts are compared.\nIf the first amount is larger than the second `1` is returned, if less than\n`-1` is returned, if both amounts are equal `0` is returned.\n\nSee `cmp/2` for a similar function that returns `:lt`, `:eq` or `:gt` instead.","ref":"Money.html#compare/2"},{"type":"function","title":"Examples - Money.compare/2","doc":"iex> Money.compare(Money.new(100, :USD), Money.new(100, :USD))\n    0\n\n    iex> Money.compare(Money.new(100, :USD), Money.new(101, :USD))\n    -1\n\n    iex> Money.compare(Money.new(101, :USD), Money.new(100, :USD))\n    1","ref":"Money.html#compare/2-examples"},{"type":"function","title":"Money.divide/2","doc":"Divides up `Money` by an amount","ref":"Money.html#divide/2"},{"type":"function","title":"Examples - Money.divide/2","doc":"iex> Money.divide(Money.new(100, :USD), 2)\n    [%Money{amount: 50, currency: :USD}, %Money{amount: 50, currency: :USD}]\n\n    iex> Money.divide(Money.new(101, :USD), 2)\n    [%Money{amount: 51, currency: :USD}, %Money{amount: 50, currency: :USD}]","ref":"Money.html#divide/2-examples"},{"type":"function","title":"Money.equals?/2","doc":"Returns true if two `Money` of the same currency have the same amount","ref":"Money.html#equals?/2"},{"type":"function","title":"Examples - Money.equals?/2","doc":"iex> Money.equals?(Money.new(100, :USD), Money.new(100, :USD))\n    true\n\n    iex> Money.equals?(Money.new(101, :USD), Money.new(100, :USD))\n    false\n\n    iex> Money.equals?(Money.new(100, :USD), Money.new(100, :CAD))\n    false","ref":"Money.html#equals?/2-examples"},{"type":"function","title":"Money.multiply/2","doc":"Multiplies a `Money` by an amount","ref":"Money.html#multiply/2"},{"type":"function","title":"Examples - Money.multiply/2","doc":"iex> Money.multiply(Money.new(100, :USD), 10)\n    %Money{amount: 1000, currency: :USD}\n\n    iex> Money.multiply(Money.new(100, :USD), 1.5)\n    %Money{amount: 150, currency: :USD}","ref":"Money.html#multiply/2-examples"},{"type":"function","title":"Money.neg/1","doc":"Returns a `Money` with the amount negated.","ref":"Money.html#neg/1"},{"type":"function","title":"Examples - Money.neg/1","doc":"iex> Money.new(100, :USD) |> Money.neg\n    %Money{amount: -100, currency: :USD}\n\n    iex> Money.new(-100, :USD) |> Money.neg\n    %Money{amount: 100, currency: :USD}","ref":"Money.html#neg/1-examples"},{"type":"function","title":"Money.negative?/1","doc":"Returns true if the amount of a `Money` is less than zero","ref":"Money.html#negative?/1"},{"type":"function","title":"Examples - Money.negative?/1","doc":"iex> Money.negative?(Money.new(0, :USD))\n    false\n\n    iex> Money.negative?(Money.new(1, :USD))\n    false\n\n    iex> Money.negative?(Money.new(-1, :USD))\n    true","ref":"Money.html#negative?/1-examples"},{"type":"function","title":"Money.new/1","doc":"Create a new `Money` struct using a default currency.\nThe default currency can be set in the system Mix config.","ref":"Money.html#new/1"},{"type":"function","title":"Config - Money.new/1","doc":"config :money,\n      default_currency: :USD","ref":"Money.html#new/1-config"},{"type":"function","title":"Examples - Money.new/1","doc":"Money.new(123)\n    %Money{amount: 123, currency: :USD}","ref":"Money.html#new/1-examples"},{"type":"function","title":"Money.new/2","doc":"Create a new `Money` struct from currency sub-units (cents)","ref":"Money.html#new/2"},{"type":"function","title":"Examples - Money.new/2","doc":"iex> Money.new(1_000_00, :USD)\n    %Money{amount: 1_000_00, currency: :USD}","ref":"Money.html#new/2-examples"},{"type":"function","title":"Money.parse/3","doc":"Parse a value into a `Money` type.\n\nThe following options are available:\n\n  * `:separator` - default `\",\"`, sets the separator for groups of thousands.\n    \"1,000\"\n  * `:delimiter` - default `\".\"`, sets the decimal delimiter.\n    \"1.23\"","ref":"Money.html#parse/3"},{"type":"function","title":"Examples - Money.parse/3","doc":"iex> Money.parse(\"$1,234.56\", :USD)\n    {:ok, %Money{amount: 123456, currency: :USD}}\n\n    iex> Money.parse(\"1.234,56\", :EUR, separator: \".\", delimiter: \",\")\n    {:ok, %Money{amount: 123456, currency: :EUR}}\n\n    iex> Money.parse(\"1.234,56\", :WRONG)\n    :error\n\n    iex> Money.parse(1_234.56, :USD)\n    {:ok, %Money{amount: 123456, currency: :USD}}\n\n    iex> Money.parse(1_234, :USD)\n    {:ok, %Money{amount: 123400, currency: :USD}}\n\n    iex> Money.parse(-1_234.56, :USD)\n    {:ok, %Money{amount: -123456, currency: :USD}}\n\n    iex> Money.parse(Decimal.from_float(1_234.56), :USD)\n    {:ok, %Money{amount: 123456, currency: :USD}}","ref":"Money.html#parse/3-examples"},{"type":"function","title":"Money.parse!/3","doc":"Parse a value into a `Money` type.\nSimilar to `parse/3` but returns a `%Money{}` or raises an error if parsing fails.","ref":"Money.html#parse!/3"},{"type":"function","title":"Examples - Money.parse!/3","doc":"iex> Money.parse!(\"1,234.56\", :USD)\n    %Money{amount: 123456, currency: :USD}\n\n    iex> Money.parse!(\"wrong\", :USD)\n    ** (ArgumentError) unable to parse \"wrong\" with currency :USD","ref":"Money.html#parse!/3-examples"},{"type":"function","title":"Money.positive?/1","doc":"Returns true if the amount of a `Money` is greater than zero","ref":"Money.html#positive?/1"},{"type":"function","title":"Examples - Money.positive?/1","doc":"iex> Money.positive?(Money.new(0, :USD))\n    false\n\n    iex> Money.positive?(Money.new(1, :USD))\n    true\n\n    iex> Money.positive?(Money.new(-1, :USD))\n    false","ref":"Money.html#positive?/1-examples"},{"type":"function","title":"Money.round/2","doc":"Rounds a `Money` struct using a given number of places. `round` respects the\nrounding mode within the current Decimal context.\n\nBy default `round` rounds to zero decimal places, using the currency's\nexponent. This results in rounding to whole values of the currency.\nCurrencies without an exponent are not rounded unless a different value is\npassed for `places` other than the default.","ref":"Money.html#round/2"},{"type":"function","title":"Examples - Money.round/2","doc":"iex> Money.round(Money.new(123456, :GBP))\n    %Money{amount: 123500, currency: :GBP}\n\n    iex> Money.round(Money.new(-123420, :EUR))\n    %Money{amount: -123400, currency: :EUR}\n\n    iex> Money.round(Money.new(-123420, :EUR), -3)\n    %Money{amount: -100000, currency: :EUR}\n\n    # Round to tenth of exponent\n    iex> Money.round(Money.new(123425, :EUR), 1)\n    %Money{amount: 123430, currency: :EUR}\n\n    # Currencies round based on their exponent\n    iex> Money.round(Money.new(820412, :JPY))\n    %Money{amount: 820412, currency: :JPY}\n\n    iex> Money.round(Money.new(820412, :JPY), -3)\n    %Money{amount: 820000, currency: :JPY}","ref":"Money.html#round/2-examples"},{"type":"function","title":"Money.subtract/2","doc":"Subtracts one `Money` from another or an integer (cents) from a `Money`","ref":"Money.html#subtract/2"},{"type":"function","title":"Examples - Money.subtract/2","doc":"iex> Money.subtract(Money.new(150, :USD), Money.new(50, :USD))\n    %Money{amount: 100, currency: :USD}\n\n    iex> Money.subtract(Money.new(150, :USD), 50)\n    %Money{amount: 100, currency: :USD}\n\n    iex> Money.subtract(Money.new(150, :USD), 1.25)\n    %Money{amount: 25, currency: :USD}","ref":"Money.html#subtract/2-examples"},{"type":"function","title":"Money.to_decimal/1","doc":"Converts a `Money` struct to a `Decimal` representation","ref":"Money.html#to_decimal/1"},{"type":"function","title":"Examples - Money.to_decimal/1","doc":"iex> Money.to_decimal(Money.new(123456, :GBP))\n    Decimal.new(\"1234.56\")\n\n    iex> Money.to_decimal(Money.new(-123420, :EUR))\n    Decimal.new(\"-1234.20\")","ref":"Money.html#to_decimal/1-examples"},{"type":"function","title":"Money.to_string/2","doc":"Converts a `Money` struct to a string representation\n\nThe following options are available:\n\n  * `:separator` - default `\",\"`, sets the separator for groups of thousands.\n    \"1,000\"\n  * `:delimiter` - default `\".\"`, sets the decimal delimiter.\n    \"1.23\"\n  * `:symbol` - default `true`, sets whether to display the currency symbol or not.\n  * `:symbol_on_right` - default `false`, display the currency symbol on the right of the number, eg: 123.45€\n  * `:symbol_space` - default `false`, add a space between currency symbol and number, eg: € 123,45 or 123.45 €\n  * `:fractional_unit` - default `true`, show the remaining units after the delimiter\n  * `:strip_insignificant_zeros` - default `false`, strip zeros after the delimiter\n  * `:code` - default `false`, append the currency code after the number\n  * `:minus_sign_first` - default `true`, display the minus sign before the currency symbol for negative values\n  * `:strip_insignificant_fractional_unit` - default `false`, don't display the delimiter or fractional units if the fractional units are only insignificant zeros","ref":"Money.html#to_string/2"},{"type":"function","title":"Examples - Money.to_string/2","doc":"iex> Money.to_string(Money.new(123456, :GBP))\n    \"£1,234.56\"\n\n    iex> Money.to_string(Money.new(123456, :EUR), separator: \".\", delimiter: \",\")\n    \"€1.234,56\"\n\n    iex> Money.to_string(Money.new(123456, :EUR), symbol: false)\n    \"1,234.56\"\n\n    iex> Money.to_string(Money.new(123456, :EUR), symbol: false, separator: \"\")\n    \"1234.56\"\n\n    iex> Money.to_string(Money.new(123456, :EUR), fractional_unit: false)\n    \"€1,234\"\n\n    iex> Money.to_string(Money.new(123450, :EUR), strip_insignificant_zeros: true)\n    \"€1,234.5\"\n\n    iex> Money.to_string(Money.new(123450, :EUR), code: true)\n    \"€1,234.50 EUR\"\n\n    iex> Money.to_string(Money.new(-123450, :EUR))\n    \"-€1,234.50\"\n\n    iex> Money.to_string(Money.new(-123450, :EUR), minus_sign_first: false)\n    \"€-1,234.50\"\n\n    iex> Money.to_string(Money.new(123400, :EUR), strip_insignificant_fractional_unit: true)\n    \"€1,234\"\n\n    iex> Money.to_string(Money.new(123450, :EUR), strip_insignificant_fractional_unit: true)\n    \"€1,234.50\"\n\nIt can also be interpolated (It implements the String.Chars protocol)\nTo control the formatting, you can use the above options in your config,\nmore information is in the introduction to `Money`","ref":"Money.html#to_string/2-examples"},{"type":"function","title":"Examples - Money.to_string/2","doc":"iex> \"Total: #{Money.new(100_00, :USD)}\"\n    \"Total: $100.00\"","ref":"Money.html#to_string/2-examples"},{"type":"function","title":"Money.zero?/1","doc":"Returns true if the amount of a `Money` struct is zero","ref":"Money.html#zero?/1"},{"type":"function","title":"Examples - Money.zero?/1","doc":"iex> Money.zero?(Money.new(0, :USD))\n    true\n\n    iex> Money.zero?(Money.new(1, :USD))\n    false","ref":"Money.html#zero?/1-examples"},{"type":"type","title":"Money.t/0","doc":"","ref":"Money.html#t:t/0"},{"type":"module","title":"Money.Currency","doc":"Provides currency support to `Money`.\n\nSome useful helper methods include:\n\n  * `get/1`\n  * `get!/1`\n  * `exists?/1`\n  * `to_atom/1`\n  * `name/1`\n  * `name!/1`\n  * `symbol/1`\n  * `symbol!/1`\n  * `all/0`\n\nA helper function exists for each currency using the lowercase three-character currency code.","ref":"Money.Currency.html"},{"type":"module","title":"Examples - Money.Currency","doc":"iex> Money.Currency.usd(100)\n    %Money{amount: 100, currency: :USD}","ref":"Money.Currency.html#module-examples"},{"type":"function","title":"Money.Currency.aed/1","doc":"Convenience method to create a `Money` object for the UAE Dirham (AED) currency.","ref":"Money.Currency.html#aed/1"},{"type":"function","title":"Examples - Money.Currency.aed/1","doc":"iex> Money.Currency.aed(100)\n    %Money{amount: 100, currency: :AED}","ref":"Money.Currency.html#aed/1-examples"},{"type":"function","title":"Money.Currency.afn/1","doc":"Convenience method to create a `Money` object for the Afghani (AFN) currency.","ref":"Money.Currency.html#afn/1"},{"type":"function","title":"Examples - Money.Currency.afn/1","doc":"iex> Money.Currency.afn(100)\n    %Money{amount: 100, currency: :AFN}","ref":"Money.Currency.html#afn/1-examples"},{"type":"function","title":"Money.Currency.all/0","doc":"Returns all the currencies","ref":"Money.Currency.html#all/0"},{"type":"function","title":"Examples - Money.Currency.all/0","doc":"iex> Money.Currency.all |> Map.fetch!(:GBP)\n    %{name: \"Pound Sterling\", symbol: \"£\", exponent: 2, number: 826}","ref":"Money.Currency.html#all/0-examples"},{"type":"function","title":"Money.Currency.all/1","doc":"Convenience method to create a `Money` object for the Lek (ALL) currency.","ref":"Money.Currency.html#all/1"},{"type":"function","title":"Examples - Money.Currency.all/1","doc":"iex> Money.Currency.all(100)\n    %Money{amount: 100, currency: :ALL}","ref":"Money.Currency.html#all/1-examples"},{"type":"function","title":"Money.Currency.amd/1","doc":"Convenience method to create a `Money` object for the Armenian Dram (AMD) currency.","ref":"Money.Currency.html#amd/1"},{"type":"function","title":"Examples - Money.Currency.amd/1","doc":"iex> Money.Currency.amd(100)\n    %Money{amount: 100, currency: :AMD}","ref":"Money.Currency.html#amd/1-examples"},{"type":"function","title":"Money.Currency.ang/1","doc":"Convenience method to create a `Money` object for the Netherlands Antillian Guilder (ANG) currency.","ref":"Money.Currency.html#ang/1"},{"type":"function","title":"Examples - Money.Currency.ang/1","doc":"iex> Money.Currency.ang(100)\n    %Money{amount: 100, currency: :ANG}","ref":"Money.Currency.html#ang/1-examples"},{"type":"function","title":"Money.Currency.aoa/1","doc":"Convenience method to create a `Money` object for the Kwanza (AOA) currency.","ref":"Money.Currency.html#aoa/1"},{"type":"function","title":"Examples - Money.Currency.aoa/1","doc":"iex> Money.Currency.aoa(100)\n    %Money{amount: 100, currency: :AOA}","ref":"Money.Currency.html#aoa/1-examples"},{"type":"function","title":"Money.Currency.ars/1","doc":"Convenience method to create a `Money` object for the Argentine Peso (ARS) currency.","ref":"Money.Currency.html#ars/1"},{"type":"function","title":"Examples - Money.Currency.ars/1","doc":"iex> Money.Currency.ars(100)\n    %Money{amount: 100, currency: :ARS}","ref":"Money.Currency.html#ars/1-examples"},{"type":"function","title":"Money.Currency.aud/1","doc":"Convenience method to create a `Money` object for the Australian Dollar (AUD) currency.","ref":"Money.Currency.html#aud/1"},{"type":"function","title":"Examples - Money.Currency.aud/1","doc":"iex> Money.Currency.aud(100)\n    %Money{amount: 100, currency: :AUD}","ref":"Money.Currency.html#aud/1-examples"},{"type":"function","title":"Money.Currency.awg/1","doc":"Convenience method to create a `Money` object for the Aruban Guilder (AWG) currency.","ref":"Money.Currency.html#awg/1"},{"type":"function","title":"Examples - Money.Currency.awg/1","doc":"iex> Money.Currency.awg(100)\n    %Money{amount: 100, currency: :AWG}","ref":"Money.Currency.html#awg/1-examples"},{"type":"function","title":"Money.Currency.azn/1","doc":"Convenience method to create a `Money` object for the Azerbaijanian Manat (AZN) currency.","ref":"Money.Currency.html#azn/1"},{"type":"function","title":"Examples - Money.Currency.azn/1","doc":"iex> Money.Currency.azn(100)\n    %Money{amount: 100, currency: :AZN}","ref":"Money.Currency.html#azn/1-examples"},{"type":"function","title":"Money.Currency.bam/1","doc":"Convenience method to create a `Money` object for the Convertible Marks (BAM) currency.","ref":"Money.Currency.html#bam/1"},{"type":"function","title":"Examples - Money.Currency.bam/1","doc":"iex> Money.Currency.bam(100)\n    %Money{amount: 100, currency: :BAM}","ref":"Money.Currency.html#bam/1-examples"},{"type":"function","title":"Money.Currency.bbd/1","doc":"Convenience method to create a `Money` object for the Barbados Dollar (BBD) currency.","ref":"Money.Currency.html#bbd/1"},{"type":"function","title":"Examples - Money.Currency.bbd/1","doc":"iex> Money.Currency.bbd(100)\n    %Money{amount: 100, currency: :BBD}","ref":"Money.Currency.html#bbd/1-examples"},{"type":"function","title":"Money.Currency.bdt/1","doc":"Convenience method to create a `Money` object for the Taka (BDT) currency.","ref":"Money.Currency.html#bdt/1"},{"type":"function","title":"Examples - Money.Currency.bdt/1","doc":"iex> Money.Currency.bdt(100)\n    %Money{amount: 100, currency: :BDT}","ref":"Money.Currency.html#bdt/1-examples"},{"type":"function","title":"Money.Currency.bgn/1","doc":"Convenience method to create a `Money` object for the Bulgarian Lev (BGN) currency.","ref":"Money.Currency.html#bgn/1"},{"type":"function","title":"Examples - Money.Currency.bgn/1","doc":"iex> Money.Currency.bgn(100)\n    %Money{amount: 100, currency: :BGN}","ref":"Money.Currency.html#bgn/1-examples"},{"type":"function","title":"Money.Currency.bhd/1","doc":"Convenience method to create a `Money` object for the Bahraini Dinar (BHD) currency.","ref":"Money.Currency.html#bhd/1"},{"type":"function","title":"Examples - Money.Currency.bhd/1","doc":"iex> Money.Currency.bhd(100)\n    %Money{amount: 100, currency: :BHD}","ref":"Money.Currency.html#bhd/1-examples"},{"type":"function","title":"Money.Currency.bif/1","doc":"Convenience method to create a `Money` object for the Burundi Franc (BIF) currency.","ref":"Money.Currency.html#bif/1"},{"type":"function","title":"Examples - Money.Currency.bif/1","doc":"iex> Money.Currency.bif(100)\n    %Money{amount: 100, currency: :BIF}","ref":"Money.Currency.html#bif/1-examples"},{"type":"function","title":"Money.Currency.bmd/1","doc":"Convenience method to create a `Money` object for the Bermudian Dollar (customarily known as Bermuda Dollar) (BMD) currency.","ref":"Money.Currency.html#bmd/1"},{"type":"function","title":"Examples - Money.Currency.bmd/1","doc":"iex> Money.Currency.bmd(100)\n    %Money{amount: 100, currency: :BMD}","ref":"Money.Currency.html#bmd/1-examples"},{"type":"function","title":"Money.Currency.bnd/1","doc":"Convenience method to create a `Money` object for the Brunei Dollar (BND) currency.","ref":"Money.Currency.html#bnd/1"},{"type":"function","title":"Examples - Money.Currency.bnd/1","doc":"iex> Money.Currency.bnd(100)\n    %Money{amount: 100, currency: :BND}","ref":"Money.Currency.html#bnd/1-examples"},{"type":"function","title":"Money.Currency.bob/1","doc":"Convenience method to create a `Money` object for the Boliviano Mvdol (BOB) currency.","ref":"Money.Currency.html#bob/1"},{"type":"function","title":"Examples - Money.Currency.bob/1","doc":"iex> Money.Currency.bob(100)\n    %Money{amount: 100, currency: :BOB}","ref":"Money.Currency.html#bob/1-examples"},{"type":"function","title":"Money.Currency.bov/1","doc":"Convenience method to create a `Money` object for the Boliviano Mvdol (BOV) currency.","ref":"Money.Currency.html#bov/1"},{"type":"function","title":"Examples - Money.Currency.bov/1","doc":"iex> Money.Currency.bov(100)\n    %Money{amount: 100, currency: :BOV}","ref":"Money.Currency.html#bov/1-examples"},{"type":"function","title":"Money.Currency.brl/1","doc":"Convenience method to create a `Money` object for the Brazilian Real (BRL) currency.","ref":"Money.Currency.html#brl/1"},{"type":"function","title":"Examples - Money.Currency.brl/1","doc":"iex> Money.Currency.brl(100)\n    %Money{amount: 100, currency: :BRL}","ref":"Money.Currency.html#brl/1-examples"},{"type":"function","title":"Money.Currency.bsd/1","doc":"Convenience method to create a `Money` object for the Bahamian Dollar (BSD) currency.","ref":"Money.Currency.html#bsd/1"},{"type":"function","title":"Examples - Money.Currency.bsd/1","doc":"iex> Money.Currency.bsd(100)\n    %Money{amount: 100, currency: :BSD}","ref":"Money.Currency.html#bsd/1-examples"},{"type":"function","title":"Money.Currency.btn/1","doc":"Convenience method to create a `Money` object for the Indian Rupee Ngultrum (BTN) currency.","ref":"Money.Currency.html#btn/1"},{"type":"function","title":"Examples - Money.Currency.btn/1","doc":"iex> Money.Currency.btn(100)\n    %Money{amount: 100, currency: :BTN}","ref":"Money.Currency.html#btn/1-examples"},{"type":"function","title":"Money.Currency.bwp/1","doc":"Convenience method to create a `Money` object for the Pula (BWP) currency.","ref":"Money.Currency.html#bwp/1"},{"type":"function","title":"Examples - Money.Currency.bwp/1","doc":"iex> Money.Currency.bwp(100)\n    %Money{amount: 100, currency: :BWP}","ref":"Money.Currency.html#bwp/1-examples"},{"type":"function","title":"Money.Currency.byn/1","doc":"Convenience method to create a `Money` object for the Belarusian Ruble (BYN) currency.","ref":"Money.Currency.html#byn/1"},{"type":"function","title":"Examples - Money.Currency.byn/1","doc":"iex> Money.Currency.byn(100)\n    %Money{amount: 100, currency: :BYN}","ref":"Money.Currency.html#byn/1-examples"},{"type":"function","title":"Money.Currency.byr/1","doc":"Convenience method to create a `Money` object for the Belarusian Ruble (BYR) currency.","ref":"Money.Currency.html#byr/1"},{"type":"function","title":"Examples - Money.Currency.byr/1","doc":"iex> Money.Currency.byr(100)\n    %Money{amount: 100, currency: :BYR}","ref":"Money.Currency.html#byr/1-examples"},{"type":"function","title":"Money.Currency.bzd/1","doc":"Convenience method to create a `Money` object for the Belize Dollar (BZD) currency.","ref":"Money.Currency.html#bzd/1"},{"type":"function","title":"Examples - Money.Currency.bzd/1","doc":"iex> Money.Currency.bzd(100)\n    %Money{amount: 100, currency: :BZD}","ref":"Money.Currency.html#bzd/1-examples"},{"type":"function","title":"Money.Currency.cad/1","doc":"Convenience method to create a `Money` object for the Canadian Dollar (CAD) currency.","ref":"Money.Currency.html#cad/1"},{"type":"function","title":"Examples - Money.Currency.cad/1","doc":"iex> Money.Currency.cad(100)\n    %Money{amount: 100, currency: :CAD}","ref":"Money.Currency.html#cad/1-examples"},{"type":"function","title":"Money.Currency.cdf/1","doc":"Convenience method to create a `Money` object for the Congolese Franc (CDF) currency.","ref":"Money.Currency.html#cdf/1"},{"type":"function","title":"Examples - Money.Currency.cdf/1","doc":"iex> Money.Currency.cdf(100)\n    %Money{amount: 100, currency: :CDF}","ref":"Money.Currency.html#cdf/1-examples"},{"type":"function","title":"Money.Currency.chf/1","doc":"Convenience method to create a `Money` object for the Swiss Franc (CHF) currency.","ref":"Money.Currency.html#chf/1"},{"type":"function","title":"Examples - Money.Currency.chf/1","doc":"iex> Money.Currency.chf(100)\n    %Money{amount: 100, currency: :CHF}","ref":"Money.Currency.html#chf/1-examples"},{"type":"function","title":"Money.Currency.clf/1","doc":"Convenience method to create a `Money` object for the Chilean Peso Unidades de fomento (CLF) currency.","ref":"Money.Currency.html#clf/1"},{"type":"function","title":"Examples - Money.Currency.clf/1","doc":"iex> Money.Currency.clf(100)\n    %Money{amount: 100, currency: :CLF}","ref":"Money.Currency.html#clf/1-examples"},{"type":"function","title":"Money.Currency.clp/1","doc":"Convenience method to create a `Money` object for the Chilean Peso Unidades de fomento (CLP) currency.","ref":"Money.Currency.html#clp/1"},{"type":"function","title":"Examples - Money.Currency.clp/1","doc":"iex> Money.Currency.clp(100)\n    %Money{amount: 100, currency: :CLP}","ref":"Money.Currency.html#clp/1-examples"},{"type":"function","title":"Money.Currency.cny/1","doc":"Convenience method to create a `Money` object for the Yuan Renminbi (CNY) currency.","ref":"Money.Currency.html#cny/1"},{"type":"function","title":"Examples - Money.Currency.cny/1","doc":"iex> Money.Currency.cny(100)\n    %Money{amount: 100, currency: :CNY}","ref":"Money.Currency.html#cny/1-examples"},{"type":"function","title":"Money.Currency.cop/1","doc":"Convenience method to create a `Money` object for the Colombian Peso (COP) currency.","ref":"Money.Currency.html#cop/1"},{"type":"function","title":"Examples - Money.Currency.cop/1","doc":"iex> Money.Currency.cop(100)\n    %Money{amount: 100, currency: :COP}","ref":"Money.Currency.html#cop/1-examples"},{"type":"function","title":"Money.Currency.cou/1","doc":"Convenience method to create a `Money` object for the Colombian Peso Unidad de Valor Real (COU) currency.","ref":"Money.Currency.html#cou/1"},{"type":"function","title":"Examples - Money.Currency.cou/1","doc":"iex> Money.Currency.cou(100)\n    %Money{amount: 100, currency: :COU}","ref":"Money.Currency.html#cou/1-examples"},{"type":"function","title":"Money.Currency.crc/1","doc":"Convenience method to create a `Money` object for the Costa Rican Colon (CRC) currency.","ref":"Money.Currency.html#crc/1"},{"type":"function","title":"Examples - Money.Currency.crc/1","doc":"iex> Money.Currency.crc(100)\n    %Money{amount: 100, currency: :CRC}","ref":"Money.Currency.html#crc/1-examples"},{"type":"function","title":"Money.Currency.cuc/1","doc":"Convenience method to create a `Money` object for the Cuban Peso Peso Convertible (CUC) currency.","ref":"Money.Currency.html#cuc/1"},{"type":"function","title":"Examples - Money.Currency.cuc/1","doc":"iex> Money.Currency.cuc(100)\n    %Money{amount: 100, currency: :CUC}","ref":"Money.Currency.html#cuc/1-examples"},{"type":"function","title":"Money.Currency.cup/1","doc":"Convenience method to create a `Money` object for the Cuban Peso Peso Convertible (CUP) currency.","ref":"Money.Currency.html#cup/1"},{"type":"function","title":"Examples - Money.Currency.cup/1","doc":"iex> Money.Currency.cup(100)\n    %Money{amount: 100, currency: :CUP}","ref":"Money.Currency.html#cup/1-examples"},{"type":"function","title":"Money.Currency.cve/1","doc":"Convenience method to create a `Money` object for the Cape Verde Escudo (CVE) currency.","ref":"Money.Currency.html#cve/1"},{"type":"function","title":"Examples - Money.Currency.cve/1","doc":"iex> Money.Currency.cve(100)\n    %Money{amount: 100, currency: :CVE}","ref":"Money.Currency.html#cve/1-examples"},{"type":"function","title":"Money.Currency.czk/1","doc":"Convenience method to create a `Money` object for the Czech Koruna (CZK) currency.","ref":"Money.Currency.html#czk/1"},{"type":"function","title":"Examples - Money.Currency.czk/1","doc":"iex> Money.Currency.czk(100)\n    %Money{amount: 100, currency: :CZK}","ref":"Money.Currency.html#czk/1-examples"},{"type":"function","title":"Money.Currency.djf/1","doc":"Convenience method to create a `Money` object for the Djibouti Franc (DJF) currency.","ref":"Money.Currency.html#djf/1"},{"type":"function","title":"Examples - Money.Currency.djf/1","doc":"iex> Money.Currency.djf(100)\n    %Money{amount: 100, currency: :DJF}","ref":"Money.Currency.html#djf/1-examples"},{"type":"function","title":"Money.Currency.dkk/1","doc":"Convenience method to create a `Money` object for the Danish Krone (DKK) currency.","ref":"Money.Currency.html#dkk/1"},{"type":"function","title":"Examples - Money.Currency.dkk/1","doc":"iex> Money.Currency.dkk(100)\n    %Money{amount: 100, currency: :DKK}","ref":"Money.Currency.html#dkk/1-examples"},{"type":"function","title":"Money.Currency.dop/1","doc":"Convenience method to create a `Money` object for the Dominican Peso (DOP) currency.","ref":"Money.Currency.html#dop/1"},{"type":"function","title":"Examples - Money.Currency.dop/1","doc":"iex> Money.Currency.dop(100)\n    %Money{amount: 100, currency: :DOP}","ref":"Money.Currency.html#dop/1-examples"},{"type":"function","title":"Money.Currency.dzd/1","doc":"Convenience method to create a `Money` object for the Algerian Dinar (DZD) currency.","ref":"Money.Currency.html#dzd/1"},{"type":"function","title":"Examples - Money.Currency.dzd/1","doc":"iex> Money.Currency.dzd(100)\n    %Money{amount: 100, currency: :DZD}","ref":"Money.Currency.html#dzd/1-examples"},{"type":"function","title":"Money.Currency.eek/1","doc":"Convenience method to create a `Money` object for the Kroon (EEK) currency.","ref":"Money.Currency.html#eek/1"},{"type":"function","title":"Examples - Money.Currency.eek/1","doc":"iex> Money.Currency.eek(100)\n    %Money{amount: 100, currency: :EEK}","ref":"Money.Currency.html#eek/1-examples"},{"type":"function","title":"Money.Currency.egp/1","doc":"Convenience method to create a `Money` object for the Egyptian Pound (EGP) currency.","ref":"Money.Currency.html#egp/1"},{"type":"function","title":"Examples - Money.Currency.egp/1","doc":"iex> Money.Currency.egp(100)\n    %Money{amount: 100, currency: :EGP}","ref":"Money.Currency.html#egp/1-examples"},{"type":"function","title":"Money.Currency.ern/1","doc":"Convenience method to create a `Money` object for the Nakfa (ERN) currency.","ref":"Money.Currency.html#ern/1"},{"type":"function","title":"Examples - Money.Currency.ern/1","doc":"iex> Money.Currency.ern(100)\n    %Money{amount: 100, currency: :ERN}","ref":"Money.Currency.html#ern/1-examples"},{"type":"function","title":"Money.Currency.etb/1","doc":"Convenience method to create a `Money` object for the Ethiopian Birr (ETB) currency.","ref":"Money.Currency.html#etb/1"},{"type":"function","title":"Examples - Money.Currency.etb/1","doc":"iex> Money.Currency.etb(100)\n    %Money{amount: 100, currency: :ETB}","ref":"Money.Currency.html#etb/1-examples"},{"type":"function","title":"Money.Currency.eur/1","doc":"Convenience method to create a `Money` object for the Euro (EUR) currency.","ref":"Money.Currency.html#eur/1"},{"type":"function","title":"Examples - Money.Currency.eur/1","doc":"iex> Money.Currency.eur(100)\n    %Money{amount: 100, currency: :EUR}","ref":"Money.Currency.html#eur/1-examples"},{"type":"function","title":"Money.Currency.exists?/1","doc":"Returns true if a currency is defined","ref":"Money.Currency.html#exists?/1"},{"type":"function","title":"Examples - Money.Currency.exists?/1","doc":"iex> Money.Currency.exists?(:USD)\n    true\n\n    iex> Money.Currency.exists?(\"USD\")\n    true\n\n    iex> Money.Currency.exists?(:WRONG)\n    false","ref":"Money.Currency.html#exists?/1-examples"},{"type":"function","title":"Money.Currency.exponent/1","doc":"Returns the exponent of the currency or nil if it doesn’t exist.","ref":"Money.Currency.html#exponent/1"},{"type":"function","title":"Examples - Money.Currency.exponent/1","doc":"iex> Money.Currency.exponent(:USD)\n    2\n\n    iex> Money.Currency.exponent(:WRONG)\n    nil","ref":"Money.Currency.html#exponent/1-examples"},{"type":"function","title":"Money.Currency.exponent!/1","doc":"Returns the exponent of the currency.\nAn ArgumentError is raised if the currency doesn’t exist.","ref":"Money.Currency.html#exponent!/1"},{"type":"function","title":"Examples - Money.Currency.exponent!/1","doc":"iex> Money.Currency.exponent!(:USD)\n    2\n\n    iex> Money.Currency.exponent!(:WRONG)\n    ** (ArgumentError) currency WRONG doesn’t exist","ref":"Money.Currency.html#exponent!/1-examples"},{"type":"function","title":"Money.Currency.fjd/1","doc":"Convenience method to create a `Money` object for the Fiji Dollar (FJD) currency.","ref":"Money.Currency.html#fjd/1"},{"type":"function","title":"Examples - Money.Currency.fjd/1","doc":"iex> Money.Currency.fjd(100)\n    %Money{amount: 100, currency: :FJD}","ref":"Money.Currency.html#fjd/1-examples"},{"type":"function","title":"Money.Currency.fkp/1","doc":"Convenience method to create a `Money` object for the Falkland Islands Pound (FKP) currency.","ref":"Money.Currency.html#fkp/1"},{"type":"function","title":"Examples - Money.Currency.fkp/1","doc":"iex> Money.Currency.fkp(100)\n    %Money{amount: 100, currency: :FKP}","ref":"Money.Currency.html#fkp/1-examples"},{"type":"function","title":"Money.Currency.gbp/1","doc":"Convenience method to create a `Money` object for the Pound Sterling (GBP) currency.","ref":"Money.Currency.html#gbp/1"},{"type":"function","title":"Examples - Money.Currency.gbp/1","doc":"iex> Money.Currency.gbp(100)\n    %Money{amount: 100, currency: :GBP}","ref":"Money.Currency.html#gbp/1-examples"},{"type":"function","title":"Money.Currency.gel/1","doc":"Convenience method to create a `Money` object for the Lari (GEL) currency.","ref":"Money.Currency.html#gel/1"},{"type":"function","title":"Examples - Money.Currency.gel/1","doc":"iex> Money.Currency.gel(100)\n    %Money{amount: 100, currency: :GEL}","ref":"Money.Currency.html#gel/1-examples"},{"type":"function","title":"Money.Currency.get/1","doc":"Returns a map with the name and symbol of the currency or nil if it doesn’t exist.","ref":"Money.Currency.html#get/1"},{"type":"function","title":"Examples - Money.Currency.get/1","doc":"iex> Money.Currency.get(:USD)\n    %{name: \"US Dollar\", symbol: \"$\", exponent: 2, number: 840}\n\n    iex> Money.Currency.get(:WRONG)\n    nil\n\n    iex> Money.Currency.get(826)\n    %{name: \"Pound Sterling\", symbol: \"£\", exponent: 2, number: 826}","ref":"Money.Currency.html#get/1-examples"},{"type":"function","title":"Money.Currency.get!/1","doc":"Returns a map with the name and symbol of the currency.\nAn ArgumentError is raised if the currency doesn’t exist.","ref":"Money.Currency.html#get!/1"},{"type":"function","title":"Examples - Money.Currency.get!/1","doc":"iex> Money.Currency.get!(:USD)\n    %{name: \"US Dollar\", symbol: \"$\", exponent: 2, number: 840}\n\n    iex> Money.Currency.get!(:WRONG)\n    ** (ArgumentError) currency WRONG doesn’t exist","ref":"Money.Currency.html#get!/1-examples"},{"type":"function","title":"Money.Currency.ghs/1","doc":"Convenience method to create a `Money` object for the Cedi (GHS) currency.","ref":"Money.Currency.html#ghs/1"},{"type":"function","title":"Examples - Money.Currency.ghs/1","doc":"iex> Money.Currency.ghs(100)\n    %Money{amount: 100, currency: :GHS}","ref":"Money.Currency.html#ghs/1-examples"},{"type":"function","title":"Money.Currency.gip/1","doc":"Convenience method to create a `Money` object for the Gibraltar Pound (GIP) currency.","ref":"Money.Currency.html#gip/1"},{"type":"function","title":"Examples - Money.Currency.gip/1","doc":"iex> Money.Currency.gip(100)\n    %Money{amount: 100, currency: :GIP}","ref":"Money.Currency.html#gip/1-examples"},{"type":"function","title":"Money.Currency.gmd/1","doc":"Convenience method to create a `Money` object for the Dalasi (GMD) currency.","ref":"Money.Currency.html#gmd/1"},{"type":"function","title":"Examples - Money.Currency.gmd/1","doc":"iex> Money.Currency.gmd(100)\n    %Money{amount: 100, currency: :GMD}","ref":"Money.Currency.html#gmd/1-examples"},{"type":"function","title":"Money.Currency.gnf/1","doc":"Convenience method to create a `Money` object for the Guinea Franc (GNF) currency.","ref":"Money.Currency.html#gnf/1"},{"type":"function","title":"Examples - Money.Currency.gnf/1","doc":"iex> Money.Currency.gnf(100)\n    %Money{amount: 100, currency: :GNF}","ref":"Money.Currency.html#gnf/1-examples"},{"type":"function","title":"Money.Currency.gtq/1","doc":"Convenience method to create a `Money` object for the Quetzal (GTQ) currency.","ref":"Money.Currency.html#gtq/1"},{"type":"function","title":"Examples - Money.Currency.gtq/1","doc":"iex> Money.Currency.gtq(100)\n    %Money{amount: 100, currency: :GTQ}","ref":"Money.Currency.html#gtq/1-examples"},{"type":"function","title":"Money.Currency.gyd/1","doc":"Convenience method to create a `Money` object for the Guyana Dollar (GYD) currency.","ref":"Money.Currency.html#gyd/1"},{"type":"function","title":"Examples - Money.Currency.gyd/1","doc":"iex> Money.Currency.gyd(100)\n    %Money{amount: 100, currency: :GYD}","ref":"Money.Currency.html#gyd/1-examples"},{"type":"function","title":"Money.Currency.hkd/1","doc":"Convenience method to create a `Money` object for the Hong Kong Dollar (HKD) currency.","ref":"Money.Currency.html#hkd/1"},{"type":"function","title":"Examples - Money.Currency.hkd/1","doc":"iex> Money.Currency.hkd(100)\n    %Money{amount: 100, currency: :HKD}","ref":"Money.Currency.html#hkd/1-examples"},{"type":"function","title":"Money.Currency.hnl/1","doc":"Convenience method to create a `Money` object for the Lempira (HNL) currency.","ref":"Money.Currency.html#hnl/1"},{"type":"function","title":"Examples - Money.Currency.hnl/1","doc":"iex> Money.Currency.hnl(100)\n    %Money{amount: 100, currency: :HNL}","ref":"Money.Currency.html#hnl/1-examples"},{"type":"function","title":"Money.Currency.hrk/1","doc":"Convenience method to create a `Money` object for the Croatian Kuna (HRK) currency.","ref":"Money.Currency.html#hrk/1"},{"type":"function","title":"Examples - Money.Currency.hrk/1","doc":"iex> Money.Currency.hrk(100)\n    %Money{amount: 100, currency: :HRK}","ref":"Money.Currency.html#hrk/1-examples"},{"type":"function","title":"Money.Currency.htg/1","doc":"Convenience method to create a `Money` object for the Gourde US Dollar (HTG) currency.","ref":"Money.Currency.html#htg/1"},{"type":"function","title":"Examples - Money.Currency.htg/1","doc":"iex> Money.Currency.htg(100)\n    %Money{amount: 100, currency: :HTG}","ref":"Money.Currency.html#htg/1-examples"},{"type":"function","title":"Money.Currency.huf/1","doc":"Convenience method to create a `Money` object for the Forint (HUF) currency.","ref":"Money.Currency.html#huf/1"},{"type":"function","title":"Examples - Money.Currency.huf/1","doc":"iex> Money.Currency.huf(100)\n    %Money{amount: 100, currency: :HUF}","ref":"Money.Currency.html#huf/1-examples"},{"type":"function","title":"Money.Currency.idr/1","doc":"Convenience method to create a `Money` object for the Rupiah (IDR) currency.","ref":"Money.Currency.html#idr/1"},{"type":"function","title":"Examples - Money.Currency.idr/1","doc":"iex> Money.Currency.idr(100)\n    %Money{amount: 100, currency: :IDR}","ref":"Money.Currency.html#idr/1-examples"},{"type":"function","title":"Money.Currency.ils/1","doc":"Convenience method to create a `Money` object for the New Israeli Sheqel (ILS) currency.","ref":"Money.Currency.html#ils/1"},{"type":"function","title":"Examples - Money.Currency.ils/1","doc":"iex> Money.Currency.ils(100)\n    %Money{amount: 100, currency: :ILS}","ref":"Money.Currency.html#ils/1-examples"},{"type":"function","title":"Money.Currency.inr/1","doc":"Convenience method to create a `Money` object for the Indian Rupee (INR) currency.","ref":"Money.Currency.html#inr/1"},{"type":"function","title":"Examples - Money.Currency.inr/1","doc":"iex> Money.Currency.inr(100)\n    %Money{amount: 100, currency: :INR}","ref":"Money.Currency.html#inr/1-examples"},{"type":"function","title":"Money.Currency.iqd/1","doc":"Convenience method to create a `Money` object for the Iraqi Dinar (IQD) currency.","ref":"Money.Currency.html#iqd/1"},{"type":"function","title":"Examples - Money.Currency.iqd/1","doc":"iex> Money.Currency.iqd(100)\n    %Money{amount: 100, currency: :IQD}","ref":"Money.Currency.html#iqd/1-examples"},{"type":"function","title":"Money.Currency.irr/1","doc":"Convenience method to create a `Money` object for the Iranian Rial (IRR) currency.","ref":"Money.Currency.html#irr/1"},{"type":"function","title":"Examples - Money.Currency.irr/1","doc":"iex> Money.Currency.irr(100)\n    %Money{amount: 100, currency: :IRR}","ref":"Money.Currency.html#irr/1-examples"},{"type":"function","title":"Money.Currency.isk/1","doc":"Convenience method to create a `Money` object for the Iceland Krona (ISK) currency.","ref":"Money.Currency.html#isk/1"},{"type":"function","title":"Examples - Money.Currency.isk/1","doc":"iex> Money.Currency.isk(100)\n    %Money{amount: 100, currency: :ISK}","ref":"Money.Currency.html#isk/1-examples"},{"type":"function","title":"Money.Currency.jmd/1","doc":"Convenience method to create a `Money` object for the Jamaican Dollar (JMD) currency.","ref":"Money.Currency.html#jmd/1"},{"type":"function","title":"Examples - Money.Currency.jmd/1","doc":"iex> Money.Currency.jmd(100)\n    %Money{amount: 100, currency: :JMD}","ref":"Money.Currency.html#jmd/1-examples"},{"type":"function","title":"Money.Currency.jod/1","doc":"Convenience method to create a `Money` object for the Jordanian Dinar (JOD) currency.","ref":"Money.Currency.html#jod/1"},{"type":"function","title":"Examples - Money.Currency.jod/1","doc":"iex> Money.Currency.jod(100)\n    %Money{amount: 100, currency: :JOD}","ref":"Money.Currency.html#jod/1-examples"},{"type":"function","title":"Money.Currency.jpy/1","doc":"Convenience method to create a `Money` object for the Yen (JPY) currency.","ref":"Money.Currency.html#jpy/1"},{"type":"function","title":"Examples - Money.Currency.jpy/1","doc":"iex> Money.Currency.jpy(100)\n    %Money{amount: 100, currency: :JPY}","ref":"Money.Currency.html#jpy/1-examples"},{"type":"function","title":"Money.Currency.kes/1","doc":"Convenience method to create a `Money` object for the Kenyan Shilling (KES) currency.","ref":"Money.Currency.html#kes/1"},{"type":"function","title":"Examples - Money.Currency.kes/1","doc":"iex> Money.Currency.kes(100)\n    %Money{amount: 100, currency: :KES}","ref":"Money.Currency.html#kes/1-examples"},{"type":"function","title":"Money.Currency.kgs/1","doc":"Convenience method to create a `Money` object for the Som (KGS) currency.","ref":"Money.Currency.html#kgs/1"},{"type":"function","title":"Examples - Money.Currency.kgs/1","doc":"iex> Money.Currency.kgs(100)\n    %Money{amount: 100, currency: :KGS}","ref":"Money.Currency.html#kgs/1-examples"},{"type":"function","title":"Money.Currency.khr/1","doc":"Convenience method to create a `Money` object for the Riel (KHR) currency.","ref":"Money.Currency.html#khr/1"},{"type":"function","title":"Examples - Money.Currency.khr/1","doc":"iex> Money.Currency.khr(100)\n    %Money{amount: 100, currency: :KHR}","ref":"Money.Currency.html#khr/1-examples"},{"type":"function","title":"Money.Currency.kmf/1","doc":"Convenience method to create a `Money` object for the Comoro Franc (KMF) currency.","ref":"Money.Currency.html#kmf/1"},{"type":"function","title":"Examples - Money.Currency.kmf/1","doc":"iex> Money.Currency.kmf(100)\n    %Money{amount: 100, currency: :KMF}","ref":"Money.Currency.html#kmf/1-examples"},{"type":"function","title":"Money.Currency.kpw/1","doc":"Convenience method to create a `Money` object for the North Korean Won (KPW) currency.","ref":"Money.Currency.html#kpw/1"},{"type":"function","title":"Examples - Money.Currency.kpw/1","doc":"iex> Money.Currency.kpw(100)\n    %Money{amount: 100, currency: :KPW}","ref":"Money.Currency.html#kpw/1-examples"},{"type":"function","title":"Money.Currency.krw/1","doc":"Convenience method to create a `Money` object for the Won (KRW) currency.","ref":"Money.Currency.html#krw/1"},{"type":"function","title":"Examples - Money.Currency.krw/1","doc":"iex> Money.Currency.krw(100)\n    %Money{amount: 100, currency: :KRW}","ref":"Money.Currency.html#krw/1-examples"},{"type":"function","title":"Money.Currency.kwd/1","doc":"Convenience method to create a `Money` object for the Kuwaiti Dinar (KWD) currency.","ref":"Money.Currency.html#kwd/1"},{"type":"function","title":"Examples - Money.Currency.kwd/1","doc":"iex> Money.Currency.kwd(100)\n    %Money{amount: 100, currency: :KWD}","ref":"Money.Currency.html#kwd/1-examples"},{"type":"function","title":"Money.Currency.kyd/1","doc":"Convenience method to create a `Money` object for the Cayman Islands Dollar (KYD) currency.","ref":"Money.Currency.html#kyd/1"},{"type":"function","title":"Examples - Money.Currency.kyd/1","doc":"iex> Money.Currency.kyd(100)\n    %Money{amount: 100, currency: :KYD}","ref":"Money.Currency.html#kyd/1-examples"},{"type":"function","title":"Money.Currency.kzt/1","doc":"Convenience method to create a `Money` object for the Tenge (KZT) currency.","ref":"Money.Currency.html#kzt/1"},{"type":"function","title":"Examples - Money.Currency.kzt/1","doc":"iex> Money.Currency.kzt(100)\n    %Money{amount: 100, currency: :KZT}","ref":"Money.Currency.html#kzt/1-examples"},{"type":"function","title":"Money.Currency.lak/1","doc":"Convenience method to create a `Money` object for the Kip (LAK) currency.","ref":"Money.Currency.html#lak/1"},{"type":"function","title":"Examples - Money.Currency.lak/1","doc":"iex> Money.Currency.lak(100)\n    %Money{amount: 100, currency: :LAK}","ref":"Money.Currency.html#lak/1-examples"},{"type":"function","title":"Money.Currency.lbp/1","doc":"Convenience method to create a `Money` object for the Lebanese Pound (LBP) currency.","ref":"Money.Currency.html#lbp/1"},{"type":"function","title":"Examples - Money.Currency.lbp/1","doc":"iex> Money.Currency.lbp(100)\n    %Money{amount: 100, currency: :LBP}","ref":"Money.Currency.html#lbp/1-examples"},{"type":"function","title":"Money.Currency.lkr/1","doc":"Convenience method to create a `Money` object for the Sri Lanka Rupee (LKR) currency.","ref":"Money.Currency.html#lkr/1"},{"type":"function","title":"Examples - Money.Currency.lkr/1","doc":"iex> Money.Currency.lkr(100)\n    %Money{amount: 100, currency: :LKR}","ref":"Money.Currency.html#lkr/1-examples"},{"type":"function","title":"Money.Currency.lrd/1","doc":"Convenience method to create a `Money` object for the Liberian Dollar (LRD) currency.","ref":"Money.Currency.html#lrd/1"},{"type":"function","title":"Examples - Money.Currency.lrd/1","doc":"iex> Money.Currency.lrd(100)\n    %Money{amount: 100, currency: :LRD}","ref":"Money.Currency.html#lrd/1-examples"},{"type":"function","title":"Money.Currency.lsl/1","doc":"Convenience method to create a `Money` object for the Rand Loti (LSL) currency.","ref":"Money.Currency.html#lsl/1"},{"type":"function","title":"Examples - Money.Currency.lsl/1","doc":"iex> Money.Currency.lsl(100)\n    %Money{amount: 100, currency: :LSL}","ref":"Money.Currency.html#lsl/1-examples"},{"type":"function","title":"Money.Currency.ltl/1","doc":"Convenience method to create a `Money` object for the Lithuanian Litas (LTL) currency.","ref":"Money.Currency.html#ltl/1"},{"type":"function","title":"Examples - Money.Currency.ltl/1","doc":"iex> Money.Currency.ltl(100)\n    %Money{amount: 100, currency: :LTL}","ref":"Money.Currency.html#ltl/1-examples"},{"type":"function","title":"Money.Currency.lvl/1","doc":"Convenience method to create a `Money` object for the Latvian Lats (LVL) currency.","ref":"Money.Currency.html#lvl/1"},{"type":"function","title":"Examples - Money.Currency.lvl/1","doc":"iex> Money.Currency.lvl(100)\n    %Money{amount: 100, currency: :LVL}","ref":"Money.Currency.html#lvl/1-examples"},{"type":"function","title":"Money.Currency.lyd/1","doc":"Convenience method to create a `Money` object for the Libyan Dinar (LYD) currency.","ref":"Money.Currency.html#lyd/1"},{"type":"function","title":"Examples - Money.Currency.lyd/1","doc":"iex> Money.Currency.lyd(100)\n    %Money{amount: 100, currency: :LYD}","ref":"Money.Currency.html#lyd/1-examples"},{"type":"function","title":"Money.Currency.mad/1","doc":"Convenience method to create a `Money` object for the Moroccan Dirham (MAD) currency.","ref":"Money.Currency.html#mad/1"},{"type":"function","title":"Examples - Money.Currency.mad/1","doc":"iex> Money.Currency.mad(100)\n    %Money{amount: 100, currency: :MAD}","ref":"Money.Currency.html#mad/1-examples"},{"type":"function","title":"Money.Currency.mdl/1","doc":"Convenience method to create a `Money` object for the Moldovan Leu (MDL) currency.","ref":"Money.Currency.html#mdl/1"},{"type":"function","title":"Examples - Money.Currency.mdl/1","doc":"iex> Money.Currency.mdl(100)\n    %Money{amount: 100, currency: :MDL}","ref":"Money.Currency.html#mdl/1-examples"},{"type":"function","title":"Money.Currency.mga/1","doc":"Convenience method to create a `Money` object for the Malagasy Ariary (MGA) currency.","ref":"Money.Currency.html#mga/1"},{"type":"function","title":"Examples - Money.Currency.mga/1","doc":"iex> Money.Currency.mga(100)\n    %Money{amount: 100, currency: :MGA}","ref":"Money.Currency.html#mga/1-examples"},{"type":"function","title":"Money.Currency.mkd/1","doc":"Convenience method to create a `Money` object for the Denar (MKD) currency.","ref":"Money.Currency.html#mkd/1"},{"type":"function","title":"Examples - Money.Currency.mkd/1","doc":"iex> Money.Currency.mkd(100)\n    %Money{amount: 100, currency: :MKD}","ref":"Money.Currency.html#mkd/1-examples"},{"type":"function","title":"Money.Currency.mmk/1","doc":"Convenience method to create a `Money` object for the Kyat (MMK) currency.","ref":"Money.Currency.html#mmk/1"},{"type":"function","title":"Examples - Money.Currency.mmk/1","doc":"iex> Money.Currency.mmk(100)\n    %Money{amount: 100, currency: :MMK}","ref":"Money.Currency.html#mmk/1-examples"},{"type":"function","title":"Money.Currency.mnt/1","doc":"Convenience method to create a `Money` object for the Tugrik (MNT) currency.","ref":"Money.Currency.html#mnt/1"},{"type":"function","title":"Examples - Money.Currency.mnt/1","doc":"iex> Money.Currency.mnt(100)\n    %Money{amount: 100, currency: :MNT}","ref":"Money.Currency.html#mnt/1-examples"},{"type":"function","title":"Money.Currency.mop/1","doc":"Convenience method to create a `Money` object for the Pataca (MOP) currency.","ref":"Money.Currency.html#mop/1"},{"type":"function","title":"Examples - Money.Currency.mop/1","doc":"iex> Money.Currency.mop(100)\n    %Money{amount: 100, currency: :MOP}","ref":"Money.Currency.html#mop/1-examples"},{"type":"function","title":"Money.Currency.mro/1","doc":"Convenience method to create a `Money` object for the Ouguiya (MRO) currency.","ref":"Money.Currency.html#mro/1"},{"type":"function","title":"Examples - Money.Currency.mro/1","doc":"iex> Money.Currency.mro(100)\n    %Money{amount: 100, currency: :MRO}","ref":"Money.Currency.html#mro/1-examples"},{"type":"function","title":"Money.Currency.mru/1","doc":"Convenience method to create a `Money` object for the Ouguiya (MRU) currency.","ref":"Money.Currency.html#mru/1"},{"type":"function","title":"Examples - Money.Currency.mru/1","doc":"iex> Money.Currency.mru(100)\n    %Money{amount: 100, currency: :MRU}","ref":"Money.Currency.html#mru/1-examples"},{"type":"function","title":"Money.Currency.mur/1","doc":"Convenience method to create a `Money` object for the Mauritius Rupee (MUR) currency.","ref":"Money.Currency.html#mur/1"},{"type":"function","title":"Examples - Money.Currency.mur/1","doc":"iex> Money.Currency.mur(100)\n    %Money{amount: 100, currency: :MUR}","ref":"Money.Currency.html#mur/1-examples"},{"type":"function","title":"Money.Currency.mvr/1","doc":"Convenience method to create a `Money` object for the Rufiyaa (MVR) currency.","ref":"Money.Currency.html#mvr/1"},{"type":"function","title":"Examples - Money.Currency.mvr/1","doc":"iex> Money.Currency.mvr(100)\n    %Money{amount: 100, currency: :MVR}","ref":"Money.Currency.html#mvr/1-examples"},{"type":"function","title":"Money.Currency.mwk/1","doc":"Convenience method to create a `Money` object for the Kwacha (MWK) currency.","ref":"Money.Currency.html#mwk/1"},{"type":"function","title":"Examples - Money.Currency.mwk/1","doc":"iex> Money.Currency.mwk(100)\n    %Money{amount: 100, currency: :MWK}","ref":"Money.Currency.html#mwk/1-examples"},{"type":"function","title":"Money.Currency.mxn/1","doc":"Convenience method to create a `Money` object for the Mexican Peso (MXN) currency.","ref":"Money.Currency.html#mxn/1"},{"type":"function","title":"Examples - Money.Currency.mxn/1","doc":"iex> Money.Currency.mxn(100)\n    %Money{amount: 100, currency: :MXN}","ref":"Money.Currency.html#mxn/1-examples"},{"type":"function","title":"Money.Currency.mxv/1","doc":"Convenience method to create a `Money` object for the Mexican Peso Mexican Unidad de Inversion (UDI) (MXV) currency.","ref":"Money.Currency.html#mxv/1"},{"type":"function","title":"Examples - Money.Currency.mxv/1","doc":"iex> Money.Currency.mxv(100)\n    %Money{amount: 100, currency: :MXV}","ref":"Money.Currency.html#mxv/1-examples"},{"type":"function","title":"Money.Currency.myr/1","doc":"Convenience method to create a `Money` object for the Malaysian Ringgit (MYR) currency.","ref":"Money.Currency.html#myr/1"},{"type":"function","title":"Examples - Money.Currency.myr/1","doc":"iex> Money.Currency.myr(100)\n    %Money{amount: 100, currency: :MYR}","ref":"Money.Currency.html#myr/1-examples"},{"type":"function","title":"Money.Currency.mzn/1","doc":"Convenience method to create a `Money` object for the Metical (MZN) currency.","ref":"Money.Currency.html#mzn/1"},{"type":"function","title":"Examples - Money.Currency.mzn/1","doc":"iex> Money.Currency.mzn(100)\n    %Money{amount: 100, currency: :MZN}","ref":"Money.Currency.html#mzn/1-examples"},{"type":"function","title":"Money.Currency.nad/1","doc":"Convenience method to create a `Money` object for the Rand Namibia Dollar (NAD) currency.","ref":"Money.Currency.html#nad/1"},{"type":"function","title":"Examples - Money.Currency.nad/1","doc":"iex> Money.Currency.nad(100)\n    %Money{amount: 100, currency: :NAD}","ref":"Money.Currency.html#nad/1-examples"},{"type":"function","title":"Money.Currency.name/1","doc":"Returns the name of the currency or nil if it doesn’t exist.","ref":"Money.Currency.html#name/1"},{"type":"function","title":"Examples - Money.Currency.name/1","doc":"iex> Money.Currency.name(:USD)\n    \"US Dollar\"\n\n    iex> Money.Currency.name(:WRONG)\n    nil","ref":"Money.Currency.html#name/1-examples"},{"type":"function","title":"Money.Currency.name!/1","doc":"Returns the name of the currency.\nAn ArgumentError is raised if the currency doesn’t exist.","ref":"Money.Currency.html#name!/1"},{"type":"function","title":"Examples - Money.Currency.name!/1","doc":"iex> Money.Currency.name!(:USD)\n    \"US Dollar\"\n\n    iex> Money.Currency.name!(:WRONG)\n    ** (ArgumentError) currency WRONG doesn’t exist","ref":"Money.Currency.html#name!/1-examples"},{"type":"function","title":"Money.Currency.ngn/1","doc":"Convenience method to create a `Money` object for the Naira (NGN) currency.","ref":"Money.Currency.html#ngn/1"},{"type":"function","title":"Examples - Money.Currency.ngn/1","doc":"iex> Money.Currency.ngn(100)\n    %Money{amount: 100, currency: :NGN}","ref":"Money.Currency.html#ngn/1-examples"},{"type":"function","title":"Money.Currency.nio/1","doc":"Convenience method to create a `Money` object for the Cordoba Oro (NIO) currency.","ref":"Money.Currency.html#nio/1"},{"type":"function","title":"Examples - Money.Currency.nio/1","doc":"iex> Money.Currency.nio(100)\n    %Money{amount: 100, currency: :NIO}","ref":"Money.Currency.html#nio/1-examples"},{"type":"function","title":"Money.Currency.nok/1","doc":"Convenience method to create a `Money` object for the Norwegian Krone (NOK) currency.","ref":"Money.Currency.html#nok/1"},{"type":"function","title":"Examples - Money.Currency.nok/1","doc":"iex> Money.Currency.nok(100)\n    %Money{amount: 100, currency: :NOK}","ref":"Money.Currency.html#nok/1-examples"},{"type":"function","title":"Money.Currency.npr/1","doc":"Convenience method to create a `Money` object for the Nepalese Rupee (NPR) currency.","ref":"Money.Currency.html#npr/1"},{"type":"function","title":"Examples - Money.Currency.npr/1","doc":"iex> Money.Currency.npr(100)\n    %Money{amount: 100, currency: :NPR}","ref":"Money.Currency.html#npr/1-examples"},{"type":"function","title":"Money.Currency.number/1","doc":"Returns the number of the currency or nil if it doesn’t exist.","ref":"Money.Currency.html#number/1"},{"type":"function","title":"Examples - Money.Currency.number/1","doc":"iex> Money.Currency.number(:USD)\n    840\n\n    iex> Money.Currency.number(:WRONG)\n    nil","ref":"Money.Currency.html#number/1-examples"},{"type":"function","title":"Money.Currency.number!/1","doc":"Returns the number of the currency.\nAn ArgumentError is raised if the currency doesn’t exist.","ref":"Money.Currency.html#number!/1"},{"type":"function","title":"Examples - Money.Currency.number!/1","doc":"iex> Money.Currency.number!(:EUR)\n    978\n\n    iex> Money.Currency.exponent!(:WRONG)\n    ** (ArgumentError) currency WRONG doesn’t exist","ref":"Money.Currency.html#number!/1-examples"},{"type":"function","title":"Money.Currency.nzd/1","doc":"Convenience method to create a `Money` object for the New Zealand Dollar (NZD) currency.","ref":"Money.Currency.html#nzd/1"},{"type":"function","title":"Examples - Money.Currency.nzd/1","doc":"iex> Money.Currency.nzd(100)\n    %Money{amount: 100, currency: :NZD}","ref":"Money.Currency.html#nzd/1-examples"},{"type":"function","title":"Money.Currency.omr/1","doc":"Convenience method to create a `Money` object for the Rial Omani (OMR) currency.","ref":"Money.Currency.html#omr/1"},{"type":"function","title":"Examples - Money.Currency.omr/1","doc":"iex> Money.Currency.omr(100)\n    %Money{amount: 100, currency: :OMR}","ref":"Money.Currency.html#omr/1-examples"},{"type":"function","title":"Money.Currency.pab/1","doc":"Convenience method to create a `Money` object for the Balboa US Dollar (PAB) currency.","ref":"Money.Currency.html#pab/1"},{"type":"function","title":"Examples - Money.Currency.pab/1","doc":"iex> Money.Currency.pab(100)\n    %Money{amount: 100, currency: :PAB}","ref":"Money.Currency.html#pab/1-examples"},{"type":"function","title":"Money.Currency.pen/1","doc":"Convenience method to create a `Money` object for the Nuevo Sol (PEN) currency.","ref":"Money.Currency.html#pen/1"},{"type":"function","title":"Examples - Money.Currency.pen/1","doc":"iex> Money.Currency.pen(100)\n    %Money{amount: 100, currency: :PEN}","ref":"Money.Currency.html#pen/1-examples"},{"type":"function","title":"Money.Currency.pgk/1","doc":"Convenience method to create a `Money` object for the Kina (PGK) currency.","ref":"Money.Currency.html#pgk/1"},{"type":"function","title":"Examples - Money.Currency.pgk/1","doc":"iex> Money.Currency.pgk(100)\n    %Money{amount: 100, currency: :PGK}","ref":"Money.Currency.html#pgk/1-examples"},{"type":"function","title":"Money.Currency.php/1","doc":"Convenience method to create a `Money` object for the Philippine Peso (PHP) currency.","ref":"Money.Currency.html#php/1"},{"type":"function","title":"Examples - Money.Currency.php/1","doc":"iex> Money.Currency.php(100)\n    %Money{amount: 100, currency: :PHP}","ref":"Money.Currency.html#php/1-examples"},{"type":"function","title":"Money.Currency.pkr/1","doc":"Convenience method to create a `Money` object for the Pakistan Rupee (PKR) currency.","ref":"Money.Currency.html#pkr/1"},{"type":"function","title":"Examples - Money.Currency.pkr/1","doc":"iex> Money.Currency.pkr(100)\n    %Money{amount: 100, currency: :PKR}","ref":"Money.Currency.html#pkr/1-examples"},{"type":"function","title":"Money.Currency.pln/1","doc":"Convenience method to create a `Money` object for the Zloty (PLN) currency.","ref":"Money.Currency.html#pln/1"},{"type":"function","title":"Examples - Money.Currency.pln/1","doc":"iex> Money.Currency.pln(100)\n    %Money{amount: 100, currency: :PLN}","ref":"Money.Currency.html#pln/1-examples"},{"type":"function","title":"Money.Currency.pyg/1","doc":"Convenience method to create a `Money` object for the Guarani (PYG) currency.","ref":"Money.Currency.html#pyg/1"},{"type":"function","title":"Examples - Money.Currency.pyg/1","doc":"iex> Money.Currency.pyg(100)\n    %Money{amount: 100, currency: :PYG}","ref":"Money.Currency.html#pyg/1-examples"},{"type":"function","title":"Money.Currency.qar/1","doc":"Convenience method to create a `Money` object for the Qatari Rial (QAR) currency.","ref":"Money.Currency.html#qar/1"},{"type":"function","title":"Examples - Money.Currency.qar/1","doc":"iex> Money.Currency.qar(100)\n    %Money{amount: 100, currency: :QAR}","ref":"Money.Currency.html#qar/1-examples"},{"type":"function","title":"Money.Currency.ron/1","doc":"Convenience method to create a `Money` object for the New Leu (RON) currency.","ref":"Money.Currency.html#ron/1"},{"type":"function","title":"Examples - Money.Currency.ron/1","doc":"iex> Money.Currency.ron(100)\n    %Money{amount: 100, currency: :RON}","ref":"Money.Currency.html#ron/1-examples"},{"type":"function","title":"Money.Currency.rsd/1","doc":"Convenience method to create a `Money` object for the Serbian Dinar (RSD) currency.","ref":"Money.Currency.html#rsd/1"},{"type":"function","title":"Examples - Money.Currency.rsd/1","doc":"iex> Money.Currency.rsd(100)\n    %Money{amount: 100, currency: :RSD}","ref":"Money.Currency.html#rsd/1-examples"},{"type":"function","title":"Money.Currency.rub/1","doc":"Convenience method to create a `Money` object for the Russian Ruble (RUB) currency.","ref":"Money.Currency.html#rub/1"},{"type":"function","title":"Examples - Money.Currency.rub/1","doc":"iex> Money.Currency.rub(100)\n    %Money{amount: 100, currency: :RUB}","ref":"Money.Currency.html#rub/1-examples"},{"type":"function","title":"Money.Currency.rwf/1","doc":"Convenience method to create a `Money` object for the Rwanda Franc (RWF) currency.","ref":"Money.Currency.html#rwf/1"},{"type":"function","title":"Examples - Money.Currency.rwf/1","doc":"iex> Money.Currency.rwf(100)\n    %Money{amount: 100, currency: :RWF}","ref":"Money.Currency.html#rwf/1-examples"},{"type":"function","title":"Money.Currency.sar/1","doc":"Convenience method to create a `Money` object for the Saudi Riyal (SAR) currency.","ref":"Money.Currency.html#sar/1"},{"type":"function","title":"Examples - Money.Currency.sar/1","doc":"iex> Money.Currency.sar(100)\n    %Money{amount: 100, currency: :SAR}","ref":"Money.Currency.html#sar/1-examples"},{"type":"function","title":"Money.Currency.sbd/1","doc":"Convenience method to create a `Money` object for the Solomon Islands Dollar (SBD) currency.","ref":"Money.Currency.html#sbd/1"},{"type":"function","title":"Examples - Money.Currency.sbd/1","doc":"iex> Money.Currency.sbd(100)\n    %Money{amount: 100, currency: :SBD}","ref":"Money.Currency.html#sbd/1-examples"},{"type":"function","title":"Money.Currency.scr/1","doc":"Convenience method to create a `Money` object for the Seychelles Rupee (SCR) currency.","ref":"Money.Currency.html#scr/1"},{"type":"function","title":"Examples - Money.Currency.scr/1","doc":"iex> Money.Currency.scr(100)\n    %Money{amount: 100, currency: :SCR}","ref":"Money.Currency.html#scr/1-examples"},{"type":"function","title":"Money.Currency.sdg/1","doc":"Convenience method to create a `Money` object for the Sudanese Pound (SDG) currency.","ref":"Money.Currency.html#sdg/1"},{"type":"function","title":"Examples - Money.Currency.sdg/1","doc":"iex> Money.Currency.sdg(100)\n    %Money{amount: 100, currency: :SDG}","ref":"Money.Currency.html#sdg/1-examples"},{"type":"function","title":"Money.Currency.sek/1","doc":"Convenience method to create a `Money` object for the Swedish Krona (SEK) currency.","ref":"Money.Currency.html#sek/1"},{"type":"function","title":"Examples - Money.Currency.sek/1","doc":"iex> Money.Currency.sek(100)\n    %Money{amount: 100, currency: :SEK}","ref":"Money.Currency.html#sek/1-examples"},{"type":"function","title":"Money.Currency.sgd/1","doc":"Convenience method to create a `Money` object for the Singapore Dollar (SGD) currency.","ref":"Money.Currency.html#sgd/1"},{"type":"function","title":"Examples - Money.Currency.sgd/1","doc":"iex> Money.Currency.sgd(100)\n    %Money{amount: 100, currency: :SGD}","ref":"Money.Currency.html#sgd/1-examples"},{"type":"function","title":"Money.Currency.shp/1","doc":"Convenience method to create a `Money` object for the Saint Helena Pound (SHP) currency.","ref":"Money.Currency.html#shp/1"},{"type":"function","title":"Examples - Money.Currency.shp/1","doc":"iex> Money.Currency.shp(100)\n    %Money{amount: 100, currency: :SHP}","ref":"Money.Currency.html#shp/1-examples"},{"type":"function","title":"Money.Currency.sle/1","doc":"Convenience method to create a `Money` object for the Leone (SLE) currency.","ref":"Money.Currency.html#sle/1"},{"type":"function","title":"Examples - Money.Currency.sle/1","doc":"iex> Money.Currency.sle(100)\n    %Money{amount: 100, currency: :SLE}","ref":"Money.Currency.html#sle/1-examples"},{"type":"function","title":"Money.Currency.sll/1","doc":"Convenience method to create a `Money` object for the Leone (SLL) currency.","ref":"Money.Currency.html#sll/1"},{"type":"function","title":"Examples - Money.Currency.sll/1","doc":"iex> Money.Currency.sll(100)\n    %Money{amount: 100, currency: :SLL}","ref":"Money.Currency.html#sll/1-examples"},{"type":"function","title":"Money.Currency.sos/1","doc":"Convenience method to create a `Money` object for the Somali Shilling (SOS) currency.","ref":"Money.Currency.html#sos/1"},{"type":"function","title":"Examples - Money.Currency.sos/1","doc":"iex> Money.Currency.sos(100)\n    %Money{amount: 100, currency: :SOS}","ref":"Money.Currency.html#sos/1-examples"},{"type":"function","title":"Money.Currency.srd/1","doc":"Convenience method to create a `Money` object for the Surinam Dollar (SRD) currency.","ref":"Money.Currency.html#srd/1"},{"type":"function","title":"Examples - Money.Currency.srd/1","doc":"iex> Money.Currency.srd(100)\n    %Money{amount: 100, currency: :SRD}","ref":"Money.Currency.html#srd/1-examples"},{"type":"function","title":"Money.Currency.ssp/1","doc":"Convenience method to create a `Money` object for the South Sudanese Pound (SSP) currency.","ref":"Money.Currency.html#ssp/1"},{"type":"function","title":"Examples - Money.Currency.ssp/1","doc":"iex> Money.Currency.ssp(100)\n    %Money{amount: 100, currency: :SSP}","ref":"Money.Currency.html#ssp/1-examples"},{"type":"function","title":"Money.Currency.std/1","doc":"Convenience method to create a `Money` object for the Dobra (STD) currency.","ref":"Money.Currency.html#std/1"},{"type":"function","title":"Examples - Money.Currency.std/1","doc":"iex> Money.Currency.std(100)\n    %Money{amount: 100, currency: :STD}","ref":"Money.Currency.html#std/1-examples"},{"type":"function","title":"Money.Currency.stn/1","doc":"Convenience method to create a `Money` object for the Dobra (STN) currency.","ref":"Money.Currency.html#stn/1"},{"type":"function","title":"Examples - Money.Currency.stn/1","doc":"iex> Money.Currency.stn(100)\n    %Money{amount: 100, currency: :STN}","ref":"Money.Currency.html#stn/1-examples"},{"type":"function","title":"Money.Currency.sub_units_count!/1","doc":"Returns the sub_units_count of the currency.\nAn ArgumentError is raised if the currency doesn’t exist.","ref":"Money.Currency.html#sub_units_count!/1"},{"type":"function","title":"Examples - Money.Currency.sub_units_count!/1","doc":"iex> Money.Currency.sub_units_count!(:USD)\n    100\n\n    iex> Money.Currency.sub_units_count!(:JPY)\n    1\n\n    iex> Money.Currency.sub_units_count!(:WRONG)\n    ** (ArgumentError) currency WRONG doesn’t exist","ref":"Money.Currency.html#sub_units_count!/1-examples"},{"type":"function","title":"Money.Currency.svc/1","doc":"Convenience method to create a `Money` object for the El Salvador Colon US Dollar (SVC) currency.","ref":"Money.Currency.html#svc/1"},{"type":"function","title":"Examples - Money.Currency.svc/1","doc":"iex> Money.Currency.svc(100)\n    %Money{amount: 100, currency: :SVC}","ref":"Money.Currency.html#svc/1-examples"},{"type":"function","title":"Money.Currency.symbol/1","doc":"Returns the symbol of the currency or nil if it doesn’t exist.","ref":"Money.Currency.html#symbol/1"},{"type":"function","title":"Examples - Money.Currency.symbol/1","doc":"iex> Money.Currency.symbol(:USD)\n    \"$\"\n\n    iex> Money.Currency.symbol(:WRONG)\n    nil","ref":"Money.Currency.html#symbol/1-examples"},{"type":"function","title":"Money.Currency.symbol!/1","doc":"Returns the symbol of the currency.\nAn ArgumentError is raised if the currency doesn’t exist.","ref":"Money.Currency.html#symbol!/1"},{"type":"function","title":"Examples - Money.Currency.symbol!/1","doc":"iex> Money.Currency.symbol!(:USD)\n    \"$\"\n\n    iex> Money.Currency.symbol!(:WRONG)\n    ** (ArgumentError) currency WRONG doesn’t exist","ref":"Money.Currency.html#symbol!/1-examples"},{"type":"function","title":"Money.Currency.syp/1","doc":"Convenience method to create a `Money` object for the Syrian Pound (SYP) currency.","ref":"Money.Currency.html#syp/1"},{"type":"function","title":"Examples - Money.Currency.syp/1","doc":"iex> Money.Currency.syp(100)\n    %Money{amount: 100, currency: :SYP}","ref":"Money.Currency.html#syp/1-examples"},{"type":"function","title":"Money.Currency.szl/1","doc":"Convenience method to create a `Money` object for the Lilangeni (SZL) currency.","ref":"Money.Currency.html#szl/1"},{"type":"function","title":"Examples - Money.Currency.szl/1","doc":"iex> Money.Currency.szl(100)\n    %Money{amount: 100, currency: :SZL}","ref":"Money.Currency.html#szl/1-examples"},{"type":"function","title":"Money.Currency.thb/1","doc":"Convenience method to create a `Money` object for the Baht (THB) currency.","ref":"Money.Currency.html#thb/1"},{"type":"function","title":"Examples - Money.Currency.thb/1","doc":"iex> Money.Currency.thb(100)\n    %Money{amount: 100, currency: :THB}","ref":"Money.Currency.html#thb/1-examples"},{"type":"function","title":"Money.Currency.tjs/1","doc":"Convenience method to create a `Money` object for the Somoni (TJS) currency.","ref":"Money.Currency.html#tjs/1"},{"type":"function","title":"Examples - Money.Currency.tjs/1","doc":"iex> Money.Currency.tjs(100)\n    %Money{amount: 100, currency: :TJS}","ref":"Money.Currency.html#tjs/1-examples"},{"type":"function","title":"Money.Currency.tmt/1","doc":"Convenience method to create a `Money` object for the Manat (TMT) currency.","ref":"Money.Currency.html#tmt/1"},{"type":"function","title":"Examples - Money.Currency.tmt/1","doc":"iex> Money.Currency.tmt(100)\n    %Money{amount: 100, currency: :TMT}","ref":"Money.Currency.html#tmt/1-examples"},{"type":"function","title":"Money.Currency.tnd/1","doc":"Convenience method to create a `Money` object for the Tunisian Dinar (TND) currency.","ref":"Money.Currency.html#tnd/1"},{"type":"function","title":"Examples - Money.Currency.tnd/1","doc":"iex> Money.Currency.tnd(100)\n    %Money{amount: 100, currency: :TND}","ref":"Money.Currency.html#tnd/1-examples"},{"type":"function","title":"Money.Currency.to_atom/1","doc":"Returns the atom representation of the currency key\nAn ArgumentError is raised if the currency doesn’t exist.","ref":"Money.Currency.html#to_atom/1"},{"type":"function","title":"Examples - Money.Currency.to_atom/1","doc":"iex> Money.Currency.to_atom(\"usd\")\n    :USD\n\n    iex> Money.Currency.to_atom(:WRONG)\n    ** (ArgumentError) currency WRONG doesn’t exist","ref":"Money.Currency.html#to_atom/1-examples"},{"type":"function","title":"Money.Currency.top/1","doc":"Convenience method to create a `Money` object for the Pa'anga (TOP) currency.","ref":"Money.Currency.html#top/1"},{"type":"function","title":"Examples - Money.Currency.top/1","doc":"iex> Money.Currency.top(100)\n    %Money{amount: 100, currency: :TOP}","ref":"Money.Currency.html#top/1-examples"},{"type":"function","title":"Money.Currency.try/1","doc":"Convenience method to create a `Money` object for the Turkish Lira (TRY) currency.","ref":"Money.Currency.html#try/1"},{"type":"function","title":"Examples - Money.Currency.try/1","doc":"iex> Money.Currency.try(100)\n    %Money{amount: 100, currency: :TRY}","ref":"Money.Currency.html#try/1-examples"},{"type":"function","title":"Money.Currency.ttd/1","doc":"Convenience method to create a `Money` object for the Trinidad and Tobago Dollar (TTD) currency.","ref":"Money.Currency.html#ttd/1"},{"type":"function","title":"Examples - Money.Currency.ttd/1","doc":"iex> Money.Currency.ttd(100)\n    %Money{amount: 100, currency: :TTD}","ref":"Money.Currency.html#ttd/1-examples"},{"type":"function","title":"Money.Currency.twd/1","doc":"Convenience method to create a `Money` object for the New Taiwan Dollar (TWD) currency.","ref":"Money.Currency.html#twd/1"},{"type":"function","title":"Examples - Money.Currency.twd/1","doc":"iex> Money.Currency.twd(100)\n    %Money{amount: 100, currency: :TWD}","ref":"Money.Currency.html#twd/1-examples"},{"type":"function","title":"Money.Currency.tzs/1","doc":"Convenience method to create a `Money` object for the Tanzanian Shilling (TZS) currency.","ref":"Money.Currency.html#tzs/1"},{"type":"function","title":"Examples - Money.Currency.tzs/1","doc":"iex> Money.Currency.tzs(100)\n    %Money{amount: 100, currency: :TZS}","ref":"Money.Currency.html#tzs/1-examples"},{"type":"function","title":"Money.Currency.uah/1","doc":"Convenience method to create a `Money` object for the Hryvnia (UAH) currency.","ref":"Money.Currency.html#uah/1"},{"type":"function","title":"Examples - Money.Currency.uah/1","doc":"iex> Money.Currency.uah(100)\n    %Money{amount: 100, currency: :UAH}","ref":"Money.Currency.html#uah/1-examples"},{"type":"function","title":"Money.Currency.ugx/1","doc":"Convenience method to create a `Money` object for the Uganda Shilling (UGX) currency.","ref":"Money.Currency.html#ugx/1"},{"type":"function","title":"Examples - Money.Currency.ugx/1","doc":"iex> Money.Currency.ugx(100)\n    %Money{amount: 100, currency: :UGX}","ref":"Money.Currency.html#ugx/1-examples"},{"type":"function","title":"Money.Currency.usd/1","doc":"Convenience method to create a `Money` object for the US Dollar (USD) currency.","ref":"Money.Currency.html#usd/1"},{"type":"function","title":"Examples - Money.Currency.usd/1","doc":"iex> Money.Currency.usd(100)\n    %Money{amount: 100, currency: :USD}","ref":"Money.Currency.html#usd/1-examples"},{"type":"function","title":"Money.Currency.usn/1","doc":"Convenience method to create a `Money` object for the US Dollar next-day funds (USN) currency.","ref":"Money.Currency.html#usn/1"},{"type":"function","title":"Examples - Money.Currency.usn/1","doc":"iex> Money.Currency.usn(100)\n    %Money{amount: 100, currency: :USN}","ref":"Money.Currency.html#usn/1-examples"},{"type":"function","title":"Money.Currency.uyi/1","doc":"Convenience method to create a `Money` object for the Peso Uruguayo Uruguay Peso en Unidades Indexadas (UYI) currency.","ref":"Money.Currency.html#uyi/1"},{"type":"function","title":"Examples - Money.Currency.uyi/1","doc":"iex> Money.Currency.uyi(100)\n    %Money{amount: 100, currency: :UYI}","ref":"Money.Currency.html#uyi/1-examples"},{"type":"function","title":"Money.Currency.uyu/1","doc":"Convenience method to create a `Money` object for the Peso Uruguayo Uruguay Peso en Unidades Indexadas (UYU) currency.","ref":"Money.Currency.html#uyu/1"},{"type":"function","title":"Examples - Money.Currency.uyu/1","doc":"iex> Money.Currency.uyu(100)\n    %Money{amount: 100, currency: :UYU}","ref":"Money.Currency.html#uyu/1-examples"},{"type":"function","title":"Money.Currency.uzs/1","doc":"Convenience method to create a `Money` object for the Uzbekistan Sum (UZS) currency.","ref":"Money.Currency.html#uzs/1"},{"type":"function","title":"Examples - Money.Currency.uzs/1","doc":"iex> Money.Currency.uzs(100)\n    %Money{amount: 100, currency: :UZS}","ref":"Money.Currency.html#uzs/1-examples"},{"type":"function","title":"Money.Currency.vef/1","doc":"Convenience method to create a `Money` object for the Bolivar Fuerte (VEF) currency.","ref":"Money.Currency.html#vef/1"},{"type":"function","title":"Examples - Money.Currency.vef/1","doc":"iex> Money.Currency.vef(100)\n    %Money{amount: 100, currency: :VEF}","ref":"Money.Currency.html#vef/1-examples"},{"type":"function","title":"Money.Currency.ves/1","doc":"Convenience method to create a `Money` object for the Venezuelan Bolivar Soberano (VES) currency.","ref":"Money.Currency.html#ves/1"},{"type":"function","title":"Examples - Money.Currency.ves/1","doc":"iex> Money.Currency.ves(100)\n    %Money{amount: 100, currency: :VES}","ref":"Money.Currency.html#ves/1-examples"},{"type":"function","title":"Money.Currency.vnd/1","doc":"Convenience method to create a `Money` object for the Dong (VND) currency.","ref":"Money.Currency.html#vnd/1"},{"type":"function","title":"Examples - Money.Currency.vnd/1","doc":"iex> Money.Currency.vnd(100)\n    %Money{amount: 100, currency: :VND}","ref":"Money.Currency.html#vnd/1-examples"},{"type":"function","title":"Money.Currency.vuv/1","doc":"Convenience method to create a `Money` object for the Vatu (VUV) currency.","ref":"Money.Currency.html#vuv/1"},{"type":"function","title":"Examples - Money.Currency.vuv/1","doc":"iex> Money.Currency.vuv(100)\n    %Money{amount: 100, currency: :VUV}","ref":"Money.Currency.html#vuv/1-examples"},{"type":"function","title":"Money.Currency.wst/1","doc":"Convenience method to create a `Money` object for the Tala (WST) currency.","ref":"Money.Currency.html#wst/1"},{"type":"function","title":"Examples - Money.Currency.wst/1","doc":"iex> Money.Currency.wst(100)\n    %Money{amount: 100, currency: :WST}","ref":"Money.Currency.html#wst/1-examples"},{"type":"function","title":"Money.Currency.xaf/1","doc":"Convenience method to create a `Money` object for the CFA Franc BEAC (XAF) currency.","ref":"Money.Currency.html#xaf/1"},{"type":"function","title":"Examples - Money.Currency.xaf/1","doc":"iex> Money.Currency.xaf(100)\n    %Money{amount: 100, currency: :XAF}","ref":"Money.Currency.html#xaf/1-examples"},{"type":"function","title":"Money.Currency.xag/1","doc":"Convenience method to create a `Money` object for the Silver (XAG) currency.","ref":"Money.Currency.html#xag/1"},{"type":"function","title":"Examples - Money.Currency.xag/1","doc":"iex> Money.Currency.xag(100)\n    %Money{amount: 100, currency: :XAG}","ref":"Money.Currency.html#xag/1-examples"},{"type":"function","title":"Money.Currency.xau/1","doc":"Convenience method to create a `Money` object for the Gold (XAU) currency.","ref":"Money.Currency.html#xau/1"},{"type":"function","title":"Examples - Money.Currency.xau/1","doc":"iex> Money.Currency.xau(100)\n    %Money{amount: 100, currency: :XAU}","ref":"Money.Currency.html#xau/1-examples"},{"type":"function","title":"Money.Currency.xba/1","doc":"Convenience method to create a `Money` object for the Bond Markets Units European Composite Unit (EURCO) (XBA) currency.","ref":"Money.Currency.html#xba/1"},{"type":"function","title":"Examples - Money.Currency.xba/1","doc":"iex> Money.Currency.xba(100)\n    %Money{amount: 100, currency: :XBA}","ref":"Money.Currency.html#xba/1-examples"},{"type":"function","title":"Money.Currency.xbb/1","doc":"Convenience method to create a `Money` object for the European Monetary Unit (E.M.U.-6) (XBB) currency.","ref":"Money.Currency.html#xbb/1"},{"type":"function","title":"Examples - Money.Currency.xbb/1","doc":"iex> Money.Currency.xbb(100)\n    %Money{amount: 100, currency: :XBB}","ref":"Money.Currency.html#xbb/1-examples"},{"type":"function","title":"Money.Currency.xbc/1","doc":"Convenience method to create a `Money` object for the European Unit of Account 9(E.U.A.-9) (XBC) currency.","ref":"Money.Currency.html#xbc/1"},{"type":"function","title":"Examples - Money.Currency.xbc/1","doc":"iex> Money.Currency.xbc(100)\n    %Money{amount: 100, currency: :XBC}","ref":"Money.Currency.html#xbc/1-examples"},{"type":"function","title":"Money.Currency.xbd/1","doc":"Convenience method to create a `Money` object for the European Unit of Account 17(E.U.A.-17) (XBD) currency.","ref":"Money.Currency.html#xbd/1"},{"type":"function","title":"Examples - Money.Currency.xbd/1","doc":"iex> Money.Currency.xbd(100)\n    %Money{amount: 100, currency: :XBD}","ref":"Money.Currency.html#xbd/1-examples"},{"type":"function","title":"Money.Currency.xcd/1","doc":"Convenience method to create a `Money` object for the East Caribbean Dollar (XCD) currency.","ref":"Money.Currency.html#xcd/1"},{"type":"function","title":"Examples - Money.Currency.xcd/1","doc":"iex> Money.Currency.xcd(100)\n    %Money{amount: 100, currency: :XCD}","ref":"Money.Currency.html#xcd/1-examples"},{"type":"function","title":"Money.Currency.xdr/1","doc":"Convenience method to create a `Money` object for the SDR (XDR) currency.","ref":"Money.Currency.html#xdr/1"},{"type":"function","title":"Examples - Money.Currency.xdr/1","doc":"iex> Money.Currency.xdr(100)\n    %Money{amount: 100, currency: :XDR}","ref":"Money.Currency.html#xdr/1-examples"},{"type":"function","title":"Money.Currency.xfu/1","doc":"Convenience method to create a `Money` object for the UIC-Franc (XFU) currency.","ref":"Money.Currency.html#xfu/1"},{"type":"function","title":"Examples - Money.Currency.xfu/1","doc":"iex> Money.Currency.xfu(100)\n    %Money{amount: 100, currency: :XFU}","ref":"Money.Currency.html#xfu/1-examples"},{"type":"function","title":"Money.Currency.xof/1","doc":"Convenience method to create a `Money` object for the CFA Franc BCEAO (XOF) currency.","ref":"Money.Currency.html#xof/1"},{"type":"function","title":"Examples - Money.Currency.xof/1","doc":"iex> Money.Currency.xof(100)\n    %Money{amount: 100, currency: :XOF}","ref":"Money.Currency.html#xof/1-examples"},{"type":"function","title":"Money.Currency.xpd/1","doc":"Convenience method to create a `Money` object for the Palladium (XPD) currency.","ref":"Money.Currency.html#xpd/1"},{"type":"function","title":"Examples - Money.Currency.xpd/1","doc":"iex> Money.Currency.xpd(100)\n    %Money{amount: 100, currency: :XPD}","ref":"Money.Currency.html#xpd/1-examples"},{"type":"function","title":"Money.Currency.xpf/1","doc":"Convenience method to create a `Money` object for the CFP Franc (XPF) currency.","ref":"Money.Currency.html#xpf/1"},{"type":"function","title":"Examples - Money.Currency.xpf/1","doc":"iex> Money.Currency.xpf(100)\n    %Money{amount: 100, currency: :XPF}","ref":"Money.Currency.html#xpf/1-examples"},{"type":"function","title":"Money.Currency.xpt/1","doc":"Convenience method to create a `Money` object for the Platinum (XPT) currency.","ref":"Money.Currency.html#xpt/1"},{"type":"function","title":"Examples - Money.Currency.xpt/1","doc":"iex> Money.Currency.xpt(100)\n    %Money{amount: 100, currency: :XPT}","ref":"Money.Currency.html#xpt/1-examples"},{"type":"function","title":"Money.Currency.xsu/1","doc":"Convenience method to create a `Money` object for the Sucre (XSU) currency.","ref":"Money.Currency.html#xsu/1"},{"type":"function","title":"Examples - Money.Currency.xsu/1","doc":"iex> Money.Currency.xsu(100)\n    %Money{amount: 100, currency: :XSU}","ref":"Money.Currency.html#xsu/1-examples"},{"type":"function","title":"Money.Currency.xts/1","doc":"Convenience method to create a `Money` object for the Codes specifically reserved for testing purposes (XTS) currency.","ref":"Money.Currency.html#xts/1"},{"type":"function","title":"Examples - Money.Currency.xts/1","doc":"iex> Money.Currency.xts(100)\n    %Money{amount: 100, currency: :XTS}","ref":"Money.Currency.html#xts/1-examples"},{"type":"function","title":"Money.Currency.xua/1","doc":"Convenience method to create a `Money` object for the ADB Unit of Account (XUA) currency.","ref":"Money.Currency.html#xua/1"},{"type":"function","title":"Examples - Money.Currency.xua/1","doc":"iex> Money.Currency.xua(100)\n    %Money{amount: 100, currency: :XUA}","ref":"Money.Currency.html#xua/1-examples"},{"type":"function","title":"Money.Currency.yer/1","doc":"Convenience method to create a `Money` object for the Yemeni Rial (YER) currency.","ref":"Money.Currency.html#yer/1"},{"type":"function","title":"Examples - Money.Currency.yer/1","doc":"iex> Money.Currency.yer(100)\n    %Money{amount: 100, currency: :YER}","ref":"Money.Currency.html#yer/1-examples"},{"type":"function","title":"Money.Currency.zar/1","doc":"Convenience method to create a `Money` object for the Rand (ZAR) currency.","ref":"Money.Currency.html#zar/1"},{"type":"function","title":"Examples - Money.Currency.zar/1","doc":"iex> Money.Currency.zar(100)\n    %Money{amount: 100, currency: :ZAR}","ref":"Money.Currency.html#zar/1-examples"},{"type":"function","title":"Money.Currency.zmw/1","doc":"Convenience method to create a `Money` object for the Zambian Kwacha (ZMW) currency.","ref":"Money.Currency.html#zmw/1"},{"type":"function","title":"Examples - Money.Currency.zmw/1","doc":"iex> Money.Currency.zmw(100)\n    %Money{amount: 100, currency: :ZMW}","ref":"Money.Currency.html#zmw/1-examples"},{"type":"function","title":"Money.Currency.zwl/1","doc":"Convenience method to create a `Money` object for the Zimbabwe Dollar (ZWL) currency.","ref":"Money.Currency.html#zwl/1"},{"type":"function","title":"Examples - Money.Currency.zwl/1","doc":"iex> Money.Currency.zwl(100)\n    %Money{amount: 100, currency: :ZWL}","ref":"Money.Currency.html#zwl/1-examples"},{"type":"type","title":"Money.Currency.index_type/0","doc":"","ref":"Money.Currency.html#t:index_type/0"},{"type":"module","title":"Money.Currency.Ecto.Type","doc":"Provides a type for Ecto to store a currency.\nThe underlying data type is a string.","ref":"Money.Currency.Ecto.Type.html"},{"type":"module","title":"Migration - Money.Currency.Ecto.Type","doc":"create table(:my_table) do\n      add :currency, :string\n    end","ref":"Money.Currency.Ecto.Type.html#module-migration"},{"type":"module","title":"Schema - Money.Currency.Ecto.Type","doc":"schema \"my_table\" do\n      field :currency, Money.Currency.Ecto.Type\n    end","ref":"Money.Currency.Ecto.Type.html#module-schema"},{"type":"function","title":"Money.Currency.Ecto.Type.cast/1","doc":"","ref":"Money.Currency.Ecto.Type.html#cast/1"},{"type":"function","title":"Money.Currency.Ecto.Type.dump/1","doc":"","ref":"Money.Currency.Ecto.Type.html#dump/1"},{"type":"function","title":"Money.Currency.Ecto.Type.embed_as/1","doc":"","ref":"Money.Currency.Ecto.Type.html#embed_as/1"},{"type":"function","title":"Money.Currency.Ecto.Type.equal?/2","doc":"","ref":"Money.Currency.Ecto.Type.html#equal?/2"},{"type":"function","title":"Money.Currency.Ecto.Type.load/1","doc":"","ref":"Money.Currency.Ecto.Type.html#load/1"},{"type":"function","title":"Money.Currency.Ecto.Type.type/0","doc":"","ref":"Money.Currency.Ecto.Type.html#type/0"},{"type":"module","title":"Money.Ecto.Amount.Type","doc":"Provides a type for Ecto to store a amount.\nThe underlying data type should be an integer.","ref":"Money.Ecto.Amount.Type.html"},{"type":"module","title":"Migration - Money.Ecto.Amount.Type","doc":"create table(:my_table) do\n      add :amount, :integer\n    end","ref":"Money.Ecto.Amount.Type.html#module-migration"},{"type":"module","title":"Schema - Money.Ecto.Amount.Type","doc":"schema \"my_table\" do\n      field :amount, Money.Ecto.Amount.Type\n    end","ref":"Money.Ecto.Amount.Type.html#module-schema"},{"type":"function","title":"Money.Ecto.Amount.Type.cast/1","doc":"","ref":"Money.Ecto.Amount.Type.html#cast/1"},{"type":"function","title":"Money.Ecto.Amount.Type.dump/1","doc":"","ref":"Money.Ecto.Amount.Type.html#dump/1"},{"type":"function","title":"Money.Ecto.Amount.Type.embed_as/1","doc":"","ref":"Money.Ecto.Amount.Type.html#embed_as/1"},{"type":"function","title":"Money.Ecto.Amount.Type.equal?/2","doc":"","ref":"Money.Ecto.Amount.Type.html#equal?/2"},{"type":"function","title":"Money.Ecto.Amount.Type.load/1","doc":"","ref":"Money.Ecto.Amount.Type.html#load/1"},{"type":"function","title":"Money.Ecto.Amount.Type.type/0","doc":"","ref":"Money.Ecto.Amount.Type.html#type/0"},{"type":"module","title":"Money.Ecto.Composite.Type","doc":"Provides a type for Ecto to store a multi-currency price.\nThe underlying data type should be an user-defined Postgres composite type `:money_with_currency`.","ref":"Money.Ecto.Composite.Type.html"},{"type":"module","title":"Migration - Money.Ecto.Composite.Type","doc":"execute \"CREATE TYPE public.money_with_currency AS (amount integer, currency varchar(3))\"\n\n    create table(:my_table) do\n      add :price, :money_with_currency\n    end","ref":"Money.Ecto.Composite.Type.html#module-migration"},{"type":"module","title":"Schema - Money.Ecto.Composite.Type","doc":"schema \"my_table\" do\n      field :price, Money.Ecto.Composite.Type\n    end","ref":"Money.Ecto.Composite.Type.html#module-schema"},{"type":"function","title":"Money.Ecto.Composite.Type.cast/1","doc":"","ref":"Money.Ecto.Composite.Type.html#cast/1"},{"type":"function","title":"Money.Ecto.Composite.Type.dump/1","doc":"","ref":"Money.Ecto.Composite.Type.html#dump/1"},{"type":"function","title":"Money.Ecto.Composite.Type.embed_as/1","doc":"","ref":"Money.Ecto.Composite.Type.html#embed_as/1"},{"type":"function","title":"Money.Ecto.Composite.Type.equal?/2","doc":"","ref":"Money.Ecto.Composite.Type.html#equal?/2"},{"type":"function","title":"Money.Ecto.Composite.Type.load/1","doc":"","ref":"Money.Ecto.Composite.Type.html#load/1"},{"type":"function","title":"Money.Ecto.Composite.Type.type/0","doc":"","ref":"Money.Ecto.Composite.Type.html#type/0"},{"type":"module","title":"Money.Ecto.Currency.Type","doc":"Provides a type for Ecto to store a currency.\nThe underlying data type is a string.","ref":"Money.Ecto.Currency.Type.html"},{"type":"module","title":"Migration - Money.Ecto.Currency.Type","doc":"create table(:my_table) do\n      add :currency, :varchar, size: 3\n    end","ref":"Money.Ecto.Currency.Type.html#module-migration"},{"type":"module","title":"Schema - Money.Ecto.Currency.Type","doc":"schema \"my_table\" do\n      field :currency, Money.Ecto.Currency.Type\n    end","ref":"Money.Ecto.Currency.Type.html#module-schema"},{"type":"function","title":"Money.Ecto.Currency.Type.cast/1","doc":"","ref":"Money.Ecto.Currency.Type.html#cast/1"},{"type":"function","title":"Money.Ecto.Currency.Type.dump/1","doc":"","ref":"Money.Ecto.Currency.Type.html#dump/1"},{"type":"function","title":"Money.Ecto.Currency.Type.embed_as/1","doc":"","ref":"Money.Ecto.Currency.Type.html#embed_as/1"},{"type":"function","title":"Money.Ecto.Currency.Type.equal?/2","doc":"","ref":"Money.Ecto.Currency.Type.html#equal?/2"},{"type":"function","title":"Money.Ecto.Currency.Type.load/1","doc":"","ref":"Money.Ecto.Currency.Type.html#load/1"},{"type":"function","title":"Money.Ecto.Currency.Type.type/0","doc":"","ref":"Money.Ecto.Currency.Type.html#type/0"},{"type":"module","title":"Money.Ecto.Map.Type","doc":"Provides a type for Ecto to store a multi-currency price.\nThe underlying data type should be a map(JSON).\nSuitable for databases that do not support composite types, but support JSON (e.g. MySQL).","ref":"Money.Ecto.Map.Type.html"},{"type":"module","title":"Migration - Money.Ecto.Map.Type","doc":"create table(:my_table) do\n      add :price, :map\n    end","ref":"Money.Ecto.Map.Type.html#module-migration"},{"type":"module","title":"Schema - Money.Ecto.Map.Type","doc":"schema \"my_table\" do\n      field :price, Money.Ecto.Map.Type\n    end","ref":"Money.Ecto.Map.Type.html#module-schema"},{"type":"function","title":"Money.Ecto.Map.Type.cast/1","doc":"","ref":"Money.Ecto.Map.Type.html#cast/1"},{"type":"function","title":"Money.Ecto.Map.Type.dump/1","doc":"","ref":"Money.Ecto.Map.Type.html#dump/1"},{"type":"function","title":"Money.Ecto.Map.Type.embed_as/1","doc":"","ref":"Money.Ecto.Map.Type.html#embed_as/1"},{"type":"function","title":"Money.Ecto.Map.Type.equal?/2","doc":"","ref":"Money.Ecto.Map.Type.html#equal?/2"},{"type":"function","title":"Money.Ecto.Map.Type.load/1","doc":"","ref":"Money.Ecto.Map.Type.html#load/1"},{"type":"function","title":"Money.Ecto.Map.Type.type/0","doc":"","ref":"Money.Ecto.Map.Type.html#type/0"},{"type":"module","title":"Money.Ecto.NumericCurrency.Type","doc":"Provides a type for Ecto to store a currency.\nThe underlying data type is a integer.","ref":"Money.Ecto.NumericCurrency.Type.html"},{"type":"module","title":"Migration - Money.Ecto.NumericCurrency.Type","doc":"create table(:my_table) do\n      add :currency, :integer\n    end","ref":"Money.Ecto.NumericCurrency.Type.html#module-migration"},{"type":"module","title":"Schema - Money.Ecto.NumericCurrency.Type","doc":"schema \"my_table\" do\n      field :currency, Money.Ecto.NumericCurrency.Type\n    end","ref":"Money.Ecto.NumericCurrency.Type.html#module-schema"},{"type":"function","title":"Money.Ecto.NumericCurrency.Type.cast/1","doc":"","ref":"Money.Ecto.NumericCurrency.Type.html#cast/1"},{"type":"function","title":"Money.Ecto.NumericCurrency.Type.dump/1","doc":"","ref":"Money.Ecto.NumericCurrency.Type.html#dump/1"},{"type":"function","title":"Money.Ecto.NumericCurrency.Type.embed_as/1","doc":"","ref":"Money.Ecto.NumericCurrency.Type.html#embed_as/1"},{"type":"function","title":"Money.Ecto.NumericCurrency.Type.equal?/2","doc":"","ref":"Money.Ecto.NumericCurrency.Type.html#equal?/2"},{"type":"function","title":"Money.Ecto.NumericCurrency.Type.load/1","doc":"","ref":"Money.Ecto.NumericCurrency.Type.html#load/1"},{"type":"function","title":"Money.Ecto.NumericCurrency.Type.type/0","doc":"","ref":"Money.Ecto.NumericCurrency.Type.html#type/0"},{"type":"module","title":"Money.Ecto.Type","doc":"**WARNING:** This module is deprecated. Use `Money.Ecto.Amount.Type` module instead.\n\nProvides a type for Ecto usage.\nThe underlying data type should be an integer.\n\nThis type expects you to use a single currency.\nThe currency must be defined in your configuration.\n\n    config :money,\n      default_currency: :GBP","ref":"Money.Ecto.Type.html"},{"type":"module","title":"Migration Example - Money.Ecto.Type","doc":"create table(:my_table) do\n      add :amount, :integer\n    end","ref":"Money.Ecto.Type.html#module-migration-example"},{"type":"module","title":"Schema Example - Money.Ecto.Type","doc":"schema \"my_table\" do\n      field :amount, Money.Ecto.Type\n    end","ref":"Money.Ecto.Type.html#module-schema-example"},{"type":"function","title":"Money.Ecto.Type.cast/1","doc":"","ref":"Money.Ecto.Type.html#cast/1"},{"type":"function","title":"Money.Ecto.Type.dump/1","doc":"","ref":"Money.Ecto.Type.html#dump/1"},{"type":"function","title":"Money.Ecto.Type.embed_as/1","doc":"","ref":"Money.Ecto.Type.html#embed_as/1"},{"type":"function","title":"Money.Ecto.Type.equal?/2","doc":"","ref":"Money.Ecto.Type.html#equal?/2"},{"type":"function","title":"Money.Ecto.Type.load/1","doc":"","ref":"Money.Ecto.Type.html#load/1"},{"type":"function","title":"Money.Ecto.Type.type/0","doc":"","ref":"Money.Ecto.Type.html#type/0"},{"type":"extras","title":"Money","doc":"# Money\n\n[![CI Status](https://github.com/elixirmoney/money/actions/workflows/ci.yml/badge.svg)](https://github.com/elixirmoney/money/actions/workflows/ci.yml)\n[![Module Version](https://img.shields.io/hexpm/v/money.svg)](https://hex.pm/packages/money)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/money/)\n[![Total Download](https://img.shields.io/hexpm/dt/money.svg)](https://hex.pm/packages/money)\n[![License](https://img.shields.io/hexpm/l/money.svg)](https://hex.pm/packages/money)\n[![Last Updated](https://img.shields.io/github/last-commit/elixirmoney/money.svg)](https://github.com/elixirmoney/money/commits/master)\n\nElixir library for working with Money safer, easier, and fun, is an interpretation of the Martin Fowler's [Money pattern](https://www.martinfowler.com/eaaCatalog/money.html) in functional programming.\n\n> \"If I had a dime for every time I've seen someone use FLOAT to store currency, I'd have \\$999.997634\" -- [Bill Karwin](https://twitter.com/billkarwin/status/347561901460447232)\n\nIn short: You shouldn't represent monetary values by a float. Wherever\nyou need to represent money, use `Money`.","ref":"readme.html"},{"type":"extras","title":"Installation - Money","doc":"Money comes with no required dependencies.\n\nAdd the following to your `mix.exs`:\n\n```elixir\ndef deps do\n  [{:money, \"~> 1.12\"}]\nend\n```\n\nthen run [`mix deps.get`](http://elixir-lang.org/getting-started/mix-otp/introduction-to-mix).","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Money","doc":"```elixir\nfive_eur         = Money.new(500, :EUR)             # %Money{amount: 500, currency: :EUR}\nten_eur          = Money.add(five_eur, five_eur)    # %Money{amount: 10_00, currency: :EUR}\nhundred_eur      = Money.multiply(ten_eur, 10)      # %Money{amount: 100_00, currency: :EUR}\nninety_nine_eur  = Money.subtract(hundred_eur, 100) # %Money{amount: 99_00, currency: :EUR}\nshares           = Money.divide(ninety_nine_eur, 2) # [%Money{amount: 4950, currency: :EUR}, %Money{amount: 4950, currency: :EUR}]\n\nMoney.equals?(five_eur, Money.new(500, :EUR)) # true\nMoney.zero?(five_eur);                        # false\nMoney.positive?(five_eur);                    # true\n\nMoney.Currency.symbol(:USD)                   # $\nMoney.Currency.symbol(Money.new(500, :AFN))   # ؋\nMoney.Currency.name(Money.new(500, :AFN))     # Afghani\n\nMoney.to_string(Money.new(500, :CNY))         # ¥ 5.00\nMoney.to_string(Money.new(1_234_56, :EUR), separator: \".\", delimiter: \",\", symbol: false)\n\"1.234,56\"\nMoney.to_string(Money.new(1_234_56, :USD), fractional_unit: false)  # \"$1,234\"\nMoney.to_string(Money.new(1_234_50, :USD), strip_insignificant_zeros: true)  # \"$1,234.5\"\n```","ref":"readme.html#usage"},{"type":"extras","title":"Serialization to database with single currency - Money","doc":"Bring `Money` to your Ecto project.\nThe underlying database type is `integer`\n\n1.  Set a default currency in `config.ex`:\n\n    ```elixir\n    config :money,\n      default_currency: :USD\n    ```\n\n2.  Create migration with integer type:\n\n    ```elixir\n    create table(:jobs) do\n      add :amount, :integer\n    end\n    ```\n\n3.  Create schema using the `Money.Ecto.Amount.Type` Ecto type (don't forget run `mix ecto.migrate`):\n\n    ```elixir\n    schema \"jobs\" do\n      field :amount, Money.Ecto.Amount.Type\n    end\n    ```\n\n4.  Save to the database:\n\n    ```elixir\n    iex(1)> Repo.insert %Job{amount: Money.new(100, :USD)}\n    [debug] QUERY OK db=90.7ms queue=0.1ms\n    INSERT INTO \"jobs\" (\"amount\",\"inserted_at\",\"updated_at\") VALUES ($1,$2,$3) RETURNING \"id\" [100, {{2019, 2, 12}, {7, 29, 8, 589489}}, {{2019, 2, 12}, {7, 29, 8, 593185}}]\n    {:ok,\n     %MoneyTest.Offers.Job{\n       __meta__: #Ecto.Schema.Metadata<:loaded, \"jobs\">,\n       amount: %Money{amount: 100, currency: :USD},\n       id: 1,\n       inserted_at: ~N[2019-02-12 07:29:08.589489],\n       updated_at: ~N[2019-02-12 07:29:08.593185]\n     }}\n    ```\n\n5.  Get from the database:\n\n    ```elixir\n    iex(2)> Repo.one(Job, limit: 1)\n    [debug] QUERY OK source=\"jobs\" db=1.8ms\n    SELECT j0.\"id\", j0.\"amount\", j0.\"inserted_at\", j0.\"updated_at\" FROM \"jobs\" AS j0 []\n    %MoneyTest.Offers.Job{\n      __meta__: #Ecto.Schema.Metadata<:loaded, \"jobs\">,\n      amount: %Money{amount: 100, currency: :USD},\n      id: 1,\n      inserted_at: ~N[2019-02-12 07:29:08.589489],\n      updated_at: ~N[2019-02-12 07:29:08.593185]\n    }\n    ```","ref":"readme.html#serialization-to-database-with-single-currency"},{"type":"extras","title":"Serialization to PostgreSQL with multiple currency - Money","doc":"`Money.Ecto.Composite.Type` Ecto type represents serialization of `Money.t` to [PostgreSQL Composite Types](https://www.postgresql.org/docs/11/rowtypes.html) with saving currency.\n\n1.  Create migration with custom type:\n\n    ```elixir\n    def up do\n      execute \"\"\"\n      CREATE TYPE public.money_with_currency AS (amount integer, currency varchar(3))\n      \"\"\"\n    end\n\n    def down do\n      execute \"\"\"\n      DROP TYPE public.money_with_currency\n      \"\"\"\n    end\n    ```\n\n2.  Then use created custom type(`money_with_currency`) for money field:\n\n    ```elixir\n    def change do\n      alter table(:jobs) do\n        add :price, :money_with_currency\n      end\n    end\n    ```\n\n3.  Create schema using the `Money.Ecto.Composite.Type` Ecto type (don't forget run `mix ecto.migrate`):\n\n    ```elixir\n    schema \"jobs\" do\n      field :price, Money.Ecto.Composite.Type\n    end\n    ```\n\n4.  Save to the database:\n\n    ```elixir\n    iex(1)> Repo.insert %Job{price: Money.new(100, :JPY)}\n    [debug] QUERY OK db=7.7ms\n    INSERT INTO \"jobs\" (\"price\",\"inserted_at\",\"updated_at\") VALUES ($1,$2,$3) RETURNING \"id\" [{100, \"JPY\"}, {{2019, 2, 12}, {8, 7, 44, 729114}}, {{2019, 2, 12}, {8, 7, 44, 729124}}]\n    {:ok,\n     %MoneyTest.Offers.Job{\n       __meta__: #Ecto.Schema.Metadata<:loaded, \"jobs\">,\n       id: 6,\n       inserted_at: ~N[2019-02-12 08:07:44.729114],\n       price: %Money{amount: 100, currency: :JPY},\n       updated_at: ~N[2019-02-12 08:07:44.729124]\n     }}\n    ```\n\n5.  Get from the database:\n\n    ```elixir\n    iex(2)> Repo.one(Job, limit: 1)\n    [debug] QUERY OK source=\"jobs\" db=1.4ms\n    SELECT j0.\"id\", j0.\"price\", j0.\"inserted_at\", j0.\"updated_at\" FROM \"jobs\" AS j0 []\n    %MoneyTest.Offers.Job{\n      __meta__: #Ecto.Schema.Metadata<:loaded, \"jobs\">,\n      id: 6,\n      inserted_at: ~N[2019-02-12 08:07:44.729114],\n      price: %Money{amount: 100, currency: :JPY},\n      updated_at: ~N[2019-02-12 08:07:44.729124]\n    }\n    ```","ref":"readme.html#serialization-to-postgresql-with-multiple-currency"},{"type":"extras","title":"Serialization to database (JSON) with multiple currency - Money","doc":"`Money.Ecto.Map.Type` Ecto type represents serialization of `Money.t` to map(JSON) with saving currency.\n\n1.  Create migration with map type:\n\n    ```elixir\n    def change do\n      alter table(:jobs) do\n        add :price, :map\n      end\n    end\n    ```\n\n2.  Create schema using the `Money.Ecto.Map.Type` Ecto type (don't forget run `mix ecto.migrate`):\n\n    ```elixir\n    schema \"jobs\" do\n      field :price, Money.Ecto.Map.Type\n    end\n    ```\n\n3.  Save to the database:\n\n    ```elixir\n    iex(1)> Repo.insert %Job{price: Money.new(100, :JPY)}\n    [debug] QUERY OK db=4.6ms\n    INSERT INTO \"jobs\" (\"price\",\"inserted_at\",\"updated_at\") VALUES ($1,$2,$3) RETURNING \"id\" [%{\"amount\" => 100, \"currency\" => \"JPY\"}, {{2019, 2, 26}, {9, 40, 14, 381721}}, {{2019, 2, 26}, {9, 40, 14, 381730}}]\n    {:ok,\n     %MoneyTest.Offers.Job{\n       __meta__: #Ecto.Schema.Metadata<:loaded, \"jobs\">,\n       id: 9,\n       inserted_at: ~N[2019-02-26 09:40:14.381721],\n       price: %Money{amount: 100, currency: :JPY},\n       updated_at: ~N[2019-02-26 09:40:14.381730]\n     }}\n    ```\n\n4.  Get from the database:\n\n    ```elixir\n    iex(8)> Repo.one(Job, limit: 1)\n    [debug] QUERY OK source=\"jobs\" db=2.0ms\n    SELECT j0.\"id\", j0.\"price\", j0.\"inserted_at\", j0.\"updated_at\" FROM \"jobs\" AS j0 []\n    %MoneyTest.Offers.Job{\n      __meta__: #Ecto.Schema.Metadata<:loaded, \"jobs\">,\n      id: 10,\n      inserted_at: ~N[2019-02-26 09:40:45.205076],\n      price: %Money{amount: 100, currency: :JPY},\n      updated_at: ~N[2019-02-26 09:40:45.205084]\n    }\n    ```","ref":"readme.html#serialization-to-database-json-with-multiple-currency"},{"type":"extras","title":"Money.Sigils - Money","doc":"```elixir\n# Sigils for Money\nimport Money.Sigils\n\niex> ~M[1000]USD\n%Money{amount: 1000, currency: :USD}\n\n# If you have a default currency configured (e.g. to GBP), you can do\niex> ~M[1000]\n%Money{amount: 1000, currency: :GBP}\n```","ref":"readme.html#money-sigils"},{"type":"extras","title":"Money.Currency - Money","doc":"```elixir\n# Currency convenience methods\nimport Money.Currency, only: [usd: 1, eur: 1, afn: 1]\n\niex> usd(100_00)\n%Money{amount: 10000, currency: :USD}\niex> eur(100_00)\n%Money{amount: 10000, currency: :EUR}\niex> afn(100_00)\n%Money{amount: 10000, currency: :AFN}\n\nMoney.Currency.symbol(:USD)     # $\nMoney.Currency.symbol(afn(500)) # ؋\nMoney.Currency.name(afn(500))   # Afghani\nMoney.Currency.get(:AFN)        # %{name: \"Afghani\", symbol: \"؋\"}\n```","ref":"readme.html#money-currency"},{"type":"extras","title":"Phoenix.HTML.Safe - Money","doc":"Bring `Money` to your Phoenix project.\nIf you are using Phoenix, you can include money objects directly into your output and they will be correctly escaped.\n\n```elixir\n <%= Money.new(12345,67, :GBP) %> \n```","ref":"readme.html#phoenix-html-safe"},{"type":"extras","title":"Configuration - Money","doc":"You can set a default currency and default formatting preferences as follows:\n\n```elixir\nconfig :money,\n  default_currency: :EUR,\n  separator: \".\",\n  delimiter: \",\",\n  symbol: false,\n  symbol_on_right: false,\n  symbol_space: false,\n  fractional_unit: true,\n  strip_insignificant_zeros: false,\n  code: false,\n  minus_sign_first: true,\n  strip_insignificant_fractional_unit: false\n```\n\nThen you don’t have to specify the currency.\n\n```elixir\niex> amount = Money.new(1_234_50)\n%Money{amount: 123450, currency: :EUR}\niex> to_string(amount)\n\"1.234,50\"\n```\n\nHere is another example of formatting money:\n\n```elixir\niex> amount = Money.new(1_234_50)\n%Money{amount: 123450, currency: :EUR}\niex> Money.to_string(amount, symbol: true, symbol_on_right: true, symbol_space: true)\n\"1.234,50 €\"\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Custom Currencies - Money","doc":"In some cases we can need to add not common currencies, like crypto currencies or others.\nIn order to add your own currencies you have to add them in the config file following this format:\n\n```elixir\nconfig :money,\n  custom_currencies: [\n    BTC: %{name: \"Bitcoin\", symbol: \"₿\", exponent: 8},\n    GCS: %{name: \"Galactic Credit Standard\", symbol: \"gcs\", exponent: 0}\n  ]\n```","ref":"readme.html#custom-currencies"},{"type":"extras","title":"Custom Currencies Display Options - Money","doc":"In some cases, we may need to display the currency in a different way than the default format. For example, we may want to display the currency symbol on the right side of the amount for some currencies. To achieve this, you can add the following configuration:\n\n```elixir\nconfig :money,\n  custom_display_options: [\n    EUR: %{symbol_on_right: true, symbol_space: true, separator: \".\", delimiter: \",\", symbol: true},\n    JPY: %{symbol_on_right: true, separator: \".\", delimiter: \",\", symbol: true}\n  ]\n```","ref":"readme.html#custom-currencies-display-options"},{"type":"extras","title":"Troubleshooting - Money","doc":"","ref":"readme.html#troubleshooting"},{"type":"extras","title":"Validating amount in Ecto changeset - Money","doc":"When using the `Money.Ecto.Amount.Type` type, it may seem that a simple value validation should work, for example:\n\n```elixir\nschema \"jobs\" do\n  field :amount, Money.Ecto.Amount.Type\nend\n\ndef changeset(struct, params \\\\ %{}) do\n  struct\n  |> cast(params, [:amount])\n  |> validate_number(:amount, [greater_than: 0])\nend\n```\n\nBut this kind of validation will not work, since under the hood `Money.Ecto.Amount.Type` has the structure `%Money{amount: ..., currency: ...}`. To validate the data in this case, we recommend adding custom validation that matches your logic.\n\nExample:\n\n```elixir\ndef changeset(struct, params \\\\ %{}) do\n  struct\n  |> cast(params, [:amount])\n  |> validate_money(:amount)\nend\n\ndefp validate_money(changeset, field) do\n  validate_change(changeset, field, fn\n    _, %Money{amount: amount} when amount > 0 -> []\n    _, _ -> [amount: \"must be greater than 0\"]\n  end)\nend\n```","ref":"readme.html#validating-amount-in-ecto-changeset"},{"type":"extras","title":"Lack of precision when using `Money.parse` - Money","doc":"Sometimes you need to work with large numbers (for example, cryptocurrencies) and `Float` precision is not enough. In this case it is better to use [Decimal](https://hex.pm/packages/decimal) package. Money already has support for Decimal and you just need to add it to your project dependencies.","ref":"readme.html#lack-of-precision-when-using-money-parse"},{"type":"extras","title":"License - Money","doc":"MIT License please see the [LICENSE.md](./LICENSE.md) file.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"1.13.1 – 2024-07-10 - Changelog","doc":"- fix release not including blend (which is a dev tool) (#229)","ref":"changelog.html#1-13-1-2024-07-10"},{"type":"extras","title":"1.13.0 – 2024-07-09 - Changelog","doc":"- Add custom_display_options configuration (#225)\n- Update Money.parse/1 to work with decimal ~> 1.2 and ~> 2.0 (#227)","ref":"changelog.html#1-13-0-2024-07-09"},{"type":"extras","title":"1.12.4 – 2024-01-04 - Changelog","doc":"- Allow phoenix_html 4.0 (#212)","ref":"changelog.html#1-12-4-2024-01-04"},{"type":"extras","title":"1.12.3 – 2023-08-23 - Changelog","doc":"- Fix map_type dump typespec (#204)\n- Add SLE which is the new currency in Sierra Leone (#203)\n- Bugfix: {Currency.Type.dump/1} missing ISO string support (#201)","ref":"changelog.html#1-12-3-2023-08-23"},{"type":"extras","title":"1.12.2 – 2023-01-19 - Changelog","doc":"- Better error messages for `Money.add` and `Monet.subtract` (#191)","ref":"changelog.html#1-12-2-2023-01-19"},{"type":"extras","title":"1.12.1 – 2022-11-23 - Changelog","doc":"This release rolls back the breaking change in Money.parse .  \nSupport exponential notation feature will be added in the next major release.","ref":"changelog.html#1-12-1-2022-11-23"},{"type":"extras","title":"🐛Bug Fixes - Changelog","doc":"- Remove support exponential notation for Money.parse (#192) (#198)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"1.12.0 – 2022-11-18 - Changelog","doc":"","ref":"changelog.html#1-12-0-2022-11-18"},{"type":"extras","title":"🚀Enhancements - Changelog","doc":"- Fix PEN currency symbol (#191)\n- Migrate from travis ci to github actions (#193)\n- Support exponential notation for Money.parse (#192)\n- Add readme section about using Decimal (#194)\n- Bump dependencies (#186)(#187)(#196)","ref":"changelog.html#enhancements"},{"type":"extras","title":"1.11.0 – 2022-08-15 - Changelog","doc":"","ref":"changelog.html#1-11-0-2022-08-15"},{"type":"extras","title":"🚀Enhancements - Changelog","doc":"- Suggest using varchar instead of char on postgres (#178)\n- Fix symbol_space with negative values (#180)\n- Fix to_string to use the minus_sign_first option (#181)\n- Adds support for strip_insignificant_fractional_unit option to to_string (#183)\n- Fix Canadian and Singaporean Dollar symbols (#185)","ref":"changelog.html#enhancements"},{"type":"extras","title":"1.10.0 – 2022-04-10 - Changelog","doc":"","ref":"changelog.html#1-10-0-2022-04-10"},{"type":"extras","title":"🚀Enhancements - Changelog","doc":"- Allow rounding Money values with Decimal (#177)\n- Parse with Decimal if present (#176)\n- Display minus sign before the currency symbol (fixes #154) (#173)","ref":"changelog.html#enhancements"},{"type":"extras","title":"1.9.0 - Changelog","doc":"","ref":"changelog.html#1-9-0"},{"type":"extras","title":"🚀Enhancements - Changelog","doc":"- Add Bolivar Soberano (#155)\n- Improve Money.to_decimal to respect decimal places (#157)\n- Add :code option for to_string rendering (#161)\n- Allow Phoenix HTML 2.0 or 3.0 (#168)\n- Support multiplying money by a decimal (#167)\n- Use the rounding algorithm set in Decimal's context (#166)","ref":"changelog.html#enhancements"},{"type":"extras","title":"🐛Bug Fixes - Changelog","doc":"- Fix bug when using Money.to_decimal with amount 0 (#158)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"1.8.0 - Changelog","doc":"","ref":"changelog.html#1-8-0"},{"type":"extras","title":"🚀Enhancements - Changelog","doc":"- Improves error message when Money.parse! fails\n- Add Money.cmp/2 function\n- Add decimal@v2.0.0 to optional list in mix.exs","ref":"changelog.html#enhancements"},{"type":"extras","title":"🐛Bug Fixes - Changelog","doc":"- Fix: avoic float rounding in Money.to_string\n- Fix some type specs (did not include valid types)\n- Fix Elixir 1.11.0 complain about variable usage\n- Fix duplicate doc for Money.Currency.get/1","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"1.7.0 - Changelog","doc":"","ref":"changelog.html#1-7-0"},{"type":"extras","title":"🚀Enhancements - Changelog","doc":"- Add Elixir 1.9 and 1.10 to CI [#97]\n- Support embedded schema for `Money.Ecto.Amount.Type` and `Money.Ecto.Map.Type` ecto types\n- Support parsing `%Decimal{}` values in `parse/3` and `parse!/3` functions\n- Support `Money.to_decimal/1` to return the value as `%Decimal{}`\n- Add currency ISO 4217 numbers support\n- `Money.equals?` no longer raises when comparing different currencies\n- `Money.parse` and `Money.parse!` now accept any number as argument","ref":"changelog.html#enhancements"},{"type":"extras","title":"1.6.1 - Changelog","doc":"","ref":"changelog.html#1-6-1"},{"type":"extras","title":"🐛Bug Fixes - Changelog","doc":"- Revert Money.Ecto.Amount.Type casting to integer. This behavior leads to the fact that the structures after casting and loading from the database are different. Details [#116](https://github.com/elixirmoney/money/issues/116)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"1.6.0 - Changelog","doc":"","ref":"changelog.html#1-6-0"},{"type":"extras","title":"🚀Enhancements - Changelog","doc":"- Strip insignificant zeros [#76]\n- Check for the new using block for Ecto.Type in Ecto 3.2 [#112]\n- Fix delimeter typo [#113]\n- Money.Ecto.Amount.Type now casting to integer [#114]","ref":"changelog.html#enhancements"},{"type":"extras","title":"1.5.1 - Changelog","doc":"","ref":"changelog.html#1-5-1"},{"type":"extras","title":"🐛Bug Fixes - Changelog","doc":"- Fix Money.Ecto.Type casting","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"1.5.0 - Changelog","doc":"","ref":"changelog.html#1-5-0"},{"type":"extras","title":"🚀Enhancements - Changelog","doc":"- Allow adding custom currencies [#108]\n- Configure custom_currencies at runtime rather than compile time [#111]\n- Add Philippine Piso sign [#104]\n- Add support to cast from atom-keyed maps [#110]\n- Fix readme typos in usage subtract and divide typos [#109]\n- Add dializer and fix warnings","ref":"changelog.html#enhancements"},{"type":"extras","title":"🐛Bug Fixes - Changelog","doc":"- Fix typos with Money.Ecto.Map.Type docs [#105]","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"1.4.0 - Changelog","doc":"Now hex is supported by an open organization and we are happy for new contributors and maintainers.","ref":"changelog.html#1-4-0"},{"type":"extras","title":"🚀Enhancements - Changelog","doc":"- Add support multiple currencies with map(JSON) type [#101]\n- Add support multiple currencies with PostgreSQL composite type [#96]\n- Add new Ecto Type for Currency [#87]\n- Add credo and fix styles [#103]\n- Formatting codebase [#102]\n- Move repo to OSS organization and fix repo links after transfer [#99]\n- Add Elixir 1.8.1 to CI [#97]","ref":"changelog.html#enhancements"},{"type":"extras","title":"⛔️Deprecations - Changelog","doc":"- Deprecate `Money.Ecto.Type`, use `Money.Ecto.Amount.Type` module instead","ref":"changelog.html#deprecations"},{"type":"extras","title":"🐛Bug Fixes - Changelog","doc":"- Fix dividing negative one [#95]\n- Fix cast in `Money.Ecto.Amount.Type` from money with currency other than a default [#100]","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"1.3.2 - Changelog","doc":"- Add Guaraní sign for PYG [#94]\n- Add new Belarusian ruble [#92]","ref":"changelog.html#1-3-2"},{"type":"extras","title":"1.3.1 - Changelog","doc":"- Support ecto 3.0 [#91]","ref":"changelog.html#1-3-1"},{"type":"extras","title":"1.3.0 - Changelog","doc":"- Support elixir 1.6 and 1.7 versions [#90]\n- Correct symbol for DKK [#86]\n- Update supported elixir versions to 1.3 [#75]\n- Fix deprecation warning for elixir 1.5 [#74]\n- Add some more symbols for currencies [#71]\n- Add some more symbols for currencies [#71]\n- Fix official RUB symbol [#70]\n- Adding a HexDoc link to the readme for faster linking to the docs [#68]\n- Allow casting a Map of ecto's embeds_many [#66]","ref":"changelog.html#1-3-0"},{"type":"extras","title":"1.2.2 - Changelog","doc":"- Fixing Mexican and Colombian pesos names [#63]\n- Add support currency exponents [#60]\n- Add ability to retrieve all currencies","ref":"changelog.html#1-2-2"},{"type":"extras","title":"1.2.1 - Changelog","doc":"- Add Money.abs/1\n- Add Money.neg/1\n- Fix issues with Money.divide/2 and negative values [#57]\n- Changes for clean compile on Elixir 1.4.1\n- Changed sigil functions to macros for compile time expansion [#59]","ref":"changelog.html#1-2-1"},{"type":"extras","title":"1.2.0 - Changelog","doc":"- Add formatting option to hide fractional units [#47]\n- Allow underscores in sigil [#48]","ref":"changelog.html#1-2-0"},{"type":"extras","title":"1.1.3 - Changelog","doc":"- Fix parsing amounts without a leading digit [#46]","ref":"changelog.html#1-1-3"},{"type":"extras","title":"1.1.2 - Changelog","doc":"- Bug fix: to_string with negative [#42]","ref":"changelog.html#1-1-2"},{"type":"extras","title":"1.1.1 - Changelog","doc":"- No changes","ref":"changelog.html#1-1-1"},{"type":"extras","title":"1.1.0 - Changelog","doc":"- Add formatting options [#36]\n- Update parse to handle negative values [#39]\n- Add support for Money.cast/1 for existing Money struct [#33]\n- Add support for Money sigil ~M [#32]\n- Add optional support for Phoenix.HTML.Safe [#29]","ref":"changelog.html#1-1-0"},{"type":"extras","title":"1.0.0 - Changelog","doc":"Initial release","ref":"changelog.html#1-0-0"},{"type":"extras","title":"Contribution Guidelines","doc":"# Contribution Guidelines","ref":"contributing.html"},{"type":"extras","title":"Steps - Contribution Guidelines","doc":"1. Fork [the repo](https://github.com/elixirmoney/money)\n2. Make sure everything is working: `mix test`\n3. Create your feature branch (`git checkout -b my-new-feature`)\n4. Make your changes\n5. Test your changes\n6. Commit your changes (`git commit -am 'Add some feature'`)\n7. If needed please squash commits.\n8. Push to the branch (`git push origin my-new-feature`)\n9. Create a Pull Request","ref":"contributing.html#steps"},{"type":"extras","title":"LICENSE","doc":"Copyright (c) 2016 Giulio De Donato\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in\nall copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN\nTHE SOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}